@@ -39,7 +39,7 @@
 
 #include "images.h"
 #include "filedialog.h"
-#include "helper.h"
+#include "paths.h"
 
 #include "shortcutgetter.h"
 
@@ -112,7 +112,14 @@ QList <QKeySequence> ActionsEditor::stringToShortcuts(QString shortcuts) {
 
 	for (int n=0; n < l.count(); n++) {
 		//qDebug("%s", l[n].toUtf8().data());
+#if QT_VERSION >= 0x040300
+		// Qt 4.3 and 4.4 (at least on linux) seems to have a problem when using Traditional Chinese
+		// QKeysequence deletes the arrow key names from the shortcut
+		// so this is a work-around.
+		QString s = l[n].simplified();
+#else
 		QString s = QKeySequence( l[n].simplified() );
+#endif
 		
 		//Work-around for Simplified-Chinese
 		s.replace( QString::fromUtf8("左"), "Left");
@@ -137,7 +144,7 @@ QList <QKeySequence> ActionsEditor::stringToShortcuts(QString shortcuts) {
 ActionsEditor::ActionsEditor(QWidget * parent, Qt::WindowFlags f)
 	: QWidget(parent, f)
 {
-	latest_dir = Helper::shortcutsPath();
+	latest_dir = Paths::shortcutsPath();
 
     actionsTable = new QTableWidget(0, COL_NAME +1, this);
 	actionsTable->setSelectionMode( QAbstractItemView::SingleSelection );
@@ -226,7 +233,7 @@ void ActionsEditor::addActions(QWidget *widget) {
 	QList<QAction *> actions = widget->findChildren<QAction *>();
 	for (int n=0; n < actions.count(); n++) {
 		action = static_cast<QAction*> (actions[n]);
-		if (!action->objectName().isEmpty())
+		if (!action->objectName().isEmpty() && !action->inherits("QWidgetAction"))
 	        actionsList.append(action);
     }
 
@@ -350,7 +357,7 @@ void ActionsEditor::validateAction(QTableWidgetItem * i) {
 void ActionsEditor::editShortcut() {
 	QTableWidgetItem * i = actionsTable->item( actionsTable->currentRow(), COL_SHORTCUT );
 	if (i) {
-		ShortcutGetter d;
+		ShortcutGetter d(this);
 		QString result = d.exec( i->text() );
 
 		if (!result.isNull()) {
@@ -536,7 +543,7 @@ void ActionsEditor::saveToConfig(QObject *o, QSettings *set) {
 	QList<QAction *> actions = o->findChildren<QAction *>();
 	for (int n=0; n < actions.count(); n++) {
 		action = static_cast<QAction*> (actions[n]);
-		if (!action->objectName().isEmpty()) {
+		if (!action->objectName().isEmpty() && !action->inherits("QWidgetAction")) {
 #if USE_MULTIPLE_SHORTCUTS
 			QString accelText = shortcutsToString(action->shortcuts());
 #else
@@ -561,7 +568,7 @@ void ActionsEditor::loadFromConfig(QObject *o, QSettings *set) {
 	QList<QAction *> actions = o->findChildren<QAction *>();
 	for (int n=0; n < actions.count(); n++) {
 		action = static_cast<QAction*> (actions[n]);
-		if (!action->objectName().isEmpty()) {
+		if (!action->objectName().isEmpty() && !action->inherits("QWidgetAction")) {
 #if USE_MULTIPLE_SHORTCUTS
 			QString current = shortcutsToString(action->shortcuts());
 			accelText = set->value(action->objectName(), current).toString();
