@@ -20,6 +20,7 @@
 #define _BASEGUI_H_
 
 #include <QMainWindow>
+#include <QNetworkProxy>
 #include "mediadata.h"
 #include "mediasettings.h"
 #include "preferences.h"
@@ -40,9 +41,11 @@ class MplayerWindow;
 class QLabel;
 class FilePropertiesDialog;
 class VideoEqualizer;
+class AudioEqualizer;
+class FindSubtitlesWindow;
+class VideoPreview;
 class Playlist;
 
-class Recents;
 class MyAction;
 class MyActionGroup;
 
@@ -66,6 +69,12 @@ public:
 	//! true or false.
 	void runActions(QString actions);
 
+	//! Execute all the actions after the video has started to play
+	void runActionsLater(QString actions) { pending_actions_to_run = actions; };
+
+	//! Saves the line from the smplayer output
+	void recordSmplayerLog(QString line);
+
 public slots:
 	virtual void open(QString file); // Generic open, autodetect type.
     virtual void openFile();
@@ -83,16 +92,26 @@ public slots:
 
 	virtual void helpFAQ();
 	virtual void helpCLOptions();
+	virtual void helpTips();
     virtual void helpAbout();
 	virtual void helpAboutQt();
 
     virtual void loadSub();
 	virtual void loadAudioFile(); // Load external audio file
 
+	void setInitialSubtitle(const QString & subtitle_file);
+
+	virtual void showFindSubtitlesDialog();
+	virtual void openUploadSubtitlesPage(); //turbos
+
+	virtual void showVideoPreviewDialog();
+
 	virtual void showPlaylist();
 	virtual void showPlaylist(bool b);
-	virtual void showEqualizer();
-	virtual void showEqualizer(bool b);
+	virtual void showVideoEqualizer();
+	virtual void showVideoEqualizer(bool b);
+	virtual void showAudioEqualizer();
+	virtual void showAudioEqualizer(bool b);
 	virtual void showMplayerLog();
     virtual void showLog();
 	virtual void showPreferencesDialog();
@@ -107,8 +126,9 @@ public slots:
 	virtual void toggleCompactMode();
 	virtual void toggleCompactMode(bool);
 
-	virtual void toggleStayOnTop();
-	virtual void toggleStayOnTop(bool);
+	void setStayOnTop(bool b);
+	virtual void changeStayOnTop(int);
+	virtual void checkStayOnTop(Core::State);
 
 	virtual void toggleFrameCounter();
 	virtual void toggleFrameCounter(bool);
@@ -134,11 +154,19 @@ protected slots:
 
     virtual void initializeMenus();
 	virtual void updateWidgets();
-	virtual void updateEqualizer();
+	virtual void updateVideoEqualizer();
+	virtual void updateAudioEqualizer();
 
 	virtual void newMediaLoaded();
 	virtual void updateMediaInfo();
 
+	void checkPendingActionsToRun();
+
+#if REPORT_OLD_MPLAYER
+	void checkMplayerVersion();
+	void displayWarningAboutOldMplayer();
+#endif
+
 #if AUTODISABLE_ACTIONS
 	virtual void enableActionsOnPlaying();
 	virtual void disableActionsOnStop();
@@ -203,15 +231,20 @@ protected slots:
 	virtual void changeStyleSheet(QString style);
 #endif
 
-#if NEW_RESIZE_CODE
-	void calculateDiff(); //!< Updates diff_size
-#endif
-
 #ifdef Q_OS_WIN
 	/* Disable screensaver by event */
 	void clear_just_stopped();
 #endif
 
+	//! Clears the mplayer log
+	void clearMplayerLog();
+
+	//! Saves the line from the mplayer output
+	void recordMplayerLog(QString line);
+
+	//! Saves the mplayer log to a file every time a file is loaded
+	void autosaveMplayerLog();
+
 signals:
 	void frameChanged(int);
 	void timeChanged(QString time_ready_to_print);
@@ -250,6 +283,7 @@ protected:
 	void createCore();
 	void createMplayerWindow();
 	void createVideoEqualizer();
+	void createAudioEqualizer();
 	void createPlaylist();
 	void createPanel();
 	void createPreferencesDialog();
@@ -265,6 +299,9 @@ protected:
 	void configureDiscDevices();
 	/* virtual void closeEvent( QCloseEvent * e ); */
 
+	//! Returns a proxy created from the user's preferences
+	QNetworkProxy userProxy();
+
 protected:
 	virtual void wheelEvent( QWheelEvent * e ) ;
 
@@ -303,16 +340,21 @@ protected:
 	MyAction * normalSpeedAct;
 	MyAction * halveSpeedAct;
 	MyAction * doubleSpeedAct;
-	MyAction * decSpeedAct;
-	MyAction * incSpeedAct;
+	MyAction * decSpeed10Act;
+	MyAction * incSpeed10Act;
+	MyAction * decSpeed4Act;
+	MyAction * incSpeed4Act;
+	MyAction * decSpeed1Act;
+	MyAction * incSpeed1Act;
 
 	// Menu Video
 	MyAction * fullscreenAct;
 	MyAction * compactAct;
-	MyAction * equalizerAct;
+	MyAction * videoEqualizerAct;
 	MyAction * screenshotAct;
-	MyAction * onTopAct;
+	MyAction * videoPreviewAct;
 	MyAction * flipAct;
+	MyAction * mirrorAct;
 	MyAction * postProcessingAct;
 	MyAction * phaseAct;
 	MyAction * deblockAct;
@@ -324,6 +366,7 @@ protected:
 	MyAction * upscaleAct;
 
 	// Menu Audio
+	MyAction * audioEqualizerAct;
 	MyAction * muteAct;
 	MyAction * decVolumeAct;
 	MyAction * incVolumeAct;
@@ -349,6 +392,8 @@ protected:
 	MyAction * useAssAct;
 	MyAction * useClosedCaptionAct;
 	MyAction * useForcedSubsOnlyAct;
+	MyAction * showFindSubtitlesDialogAct;
+	MyAction * openUploadSubtitlesPageAct;//turbos  
 
 	// Menu Options
 	MyAction * showPlaylistAct;
@@ -361,7 +406,8 @@ protected:
 
 	// Menu Help
 	MyAction * showFAQAct;
-	MyAction * showCLOptions; // Command line options
+	MyAction * showCLOptionsAct; // Command line options
+    MyAction * showTipsAct;
 	MyAction * aboutQtAct;
 	MyAction * aboutThisAct;
 
@@ -386,13 +432,18 @@ protected:
 	MyAction * incSaturationAct;
 	MyAction * decGammaAct;
 	MyAction * incGammaAct;
+	MyAction * nextVideoAct;
 	MyAction * nextAudioAct;
 	MyAction * nextSubtitleAct;
 	MyAction * nextChapterAct;
 	MyAction * prevChapterAct;
 	MyAction * doubleSizeAct;
 	MyAction * resetVideoEqualizerAct;
+	MyAction * resetAudioEqualizerAct;
 	MyAction * showContextMenuAct;
+#if NEW_ASPECT_CODE
+	MyAction * nextAspectAct;
+#endif
 
 	// Moving and zoom
 	MyAction * moveUpAct;
@@ -402,6 +453,9 @@ protected:
 	MyAction * incZoomAct;
 	MyAction * decZoomAct;
 	MyAction * resetZoomAct;
+	MyAction * autoZoomAct;
+	MyAction * autoZoom169Act;
+	MyAction * autoZoom235Act;
 
 	// OSD Action Group 
 	MyActionGroup * osdGroup;
@@ -440,6 +494,10 @@ protected:
 	// Aspect Action Group
 	MyActionGroup * aspectGroup;
 	MyAction * aspectDetectAct;
+#if NEW_ASPECT_CODE
+	MyAction * aspectNoneAct;
+	MyAction * aspect11Act; // 1:1
+#endif
 	MyAction * aspect43Act;
 	MyAction * aspect54Act;
 	MyAction * aspect149Act;
@@ -461,6 +519,18 @@ protected:
 	MyAction * rotateCounterclockwiseAct;
 	MyAction * rotateCounterclockwiseFlipAct;
 
+	// Menu StayOnTop
+	MyActionGroup * onTopActionGroup;
+	MyAction * onTopAlwaysAct;
+	MyAction * onTopNeverAct;
+	MyAction * onTopWhilePlayingAct;
+
+#if USE_ADAPTER
+	// Screen Group
+	MyActionGroup * screenGroup;
+	MyAction * screenDefaultAct;
+#endif
+
 	// Audio Channels Action Group
 	MyActionGroup * channelsGroup;
 	/* MyAction * channelsDefaultAct; */
@@ -475,12 +545,23 @@ protected:
 	MyAction * rightChannelAct;
 
 	// Other groups
+	MyActionGroup * videoTrackGroup;
 	MyActionGroup * audioTrackGroup;
 	MyActionGroup * subtitleTrackGroup;
 	MyActionGroup * titleGroup;
 	MyActionGroup * angleGroup;
 	MyActionGroup * chapterGroup;
 
+#if DVDNAV_SUPPORT
+	MyAction * dvdnavUpAct;
+	MyAction * dvdnavDownAct;
+	MyAction * dvdnavLeftAct;
+	MyAction * dvdnavRightAct;
+	MyAction * dvdnavMenuAct;
+	MyAction * dvdnavSelectAct;
+	MyAction * dvdnavPrevAct;
+	MyAction * dvdnavMouseAct;
+#endif
 
 	// MENUS
 	QMenu *openMenu;
@@ -493,6 +574,7 @@ protected:
     QMenu *helpMenu;
 
 	QMenu * subtitlestrack_menu;
+	QMenu * videotrack_menu;
 	QMenu * audiotrack_menu;
 	QMenu * titles_menu;
 	QMenu * chapters_menu;
@@ -511,6 +593,10 @@ protected:
 	QMenu * logs_menu;
 	QMenu * panscan_menu;
 	QMenu * rotate_menu;
+	QMenu * ontop_menu;
+#if USE_ADAPTER
+	QMenu * screen_menu;
+#endif
 
 	QMenu * popup;
 	QMenu * recentfiles_menu;
@@ -522,17 +608,20 @@ protected:
 	PreferencesDialog *pref_dialog;
 	FilePropertiesDialog *file_dialog;
 	Playlist * playlist;
-	VideoEqualizer * equalizer;
+	VideoEqualizer * video_equalizer;
+	AudioEqualizer * audio_equalizer;
+	FindSubtitlesWindow * find_subs_dialog;
+	VideoPreview * video_preview;
 
 	Core * core;
     MplayerWindow *mplayerwindow;
 
-	Recents * recents;
-
 	MyServer * server;
 
 	QStringList actions_list;
 
+	QString pending_actions_to_run;
+
 private:
 	QString default_style;
 
@@ -545,15 +634,15 @@ private:
 	QSize win_size;
 	bool was_maximized;
 
-#if NEW_RESIZE_CODE
-	QSize diff_size;	//!< Main window size - panel size
-#endif
-
 #ifdef Q_OS_WIN
 	/* Disable screensaver by event */
 	bool just_stopped;
 #endif
 
+	QString mplayer_log;
+	QString smplayer_log;
+
+	bool ignore_show_hide_events;
 };
     
 #endif
