@@ -27,6 +27,8 @@
 
 #include <QMenu>
 #include <QCloseEvent>
+#include <QApplication>
+#include <QDesktopWidget>
 
 #if DOCK_PLAYLIST
 #include <QDockWidget>
@@ -76,6 +78,7 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags )
 	connect( showAllAct, SIGNAL(triggered()),
              this, SLOT(toggleShowAll()) );
 
+
 	context_menu = new QMenu(this);
 	context_menu->addAction(showAllAct);
 	context_menu->addSeparator();
@@ -116,11 +119,16 @@ BaseGuiPlus::BaseGuiPlus( QWidget * parent, Qt::WindowFlags flags )
 	playlistdock->setFloating(true); // Floating by default
 
 	connect( playlistdock, SIGNAL(closed()), this, SLOT(playlistClosed()) );
-	connect( playlistdock, SIGNAL(docked()), this, SLOT(stretchWindow()) );
-	connect( playlistdock, SIGNAL(undocked()), this, SLOT(shrinkWindow()) );
+#if USE_DOCK_TOPLEVEL_EVENT
+	connect( playlistdock, SIGNAL(topLevelChanged(bool)), 
+             this, SLOT(dockTopLevelChanged(bool)) );
+#else
+	connect( playlistdock, SIGNAL(visibilityChanged(bool)), 
+             this, SLOT(dockVisibilityChanged(bool)) );
+#endif // USE_DOCK_TOPLEVEL_EVENT
 
 	ignore_playlist_events = false;
-#endif
+#endif // DOCK_PLAYLIST
 
 	retranslateStrings();
 
@@ -361,14 +369,22 @@ void BaseGuiPlus::aboutToEnterFullscreen() {
 	BaseGui::aboutToEnterFullscreen();
 
 #if DOCK_PLAYLIST
+	int playlist_screen = QApplication::desktop()->screenNumber(playlistdock);
+	int mainwindow_screen = QApplication::desktop()->screenNumber(this);
+	qDebug("BaseGuiPlus::aboutToEnterFullscreen: mainwindow screen: %d, playlist screen: %d", mainwindow_screen, playlist_screen);
+
 	fullscreen_playlist_was_visible = playlistdock->isVisible();
 	fullscreen_playlist_was_floating = playlistdock->isFloating();
-	//showPlaylistAct->setEnabled(false);
+
 	ignore_playlist_events = true;
-	playlistdock->setFloating(true);
-	playlistdock->hide();
-	//showPlaylistAct->setChecked(false);
-	//playlist_state = saveState();
+
+	// Hide the playlist if it's in the same screen as the main window
+	if ((playlist_screen == mainwindow_screen) /* || 
+        (!fullscreen_playlist_was_floating) */ ) 
+	{
+		playlistdock->setFloating(true);
+		playlistdock->hide();
+	}
 #endif
 }
 
@@ -382,9 +398,7 @@ void BaseGuiPlus::aboutToExitFullscreen() {
 		playlistdock->show();
 	}
 	playlistdock->setFloating( fullscreen_playlist_was_floating );
-	//restoreState( playlist_state );
 	ignore_playlist_events = false;
-	//showPlaylistAct->setEnabled(true);
 #endif
 }
 
@@ -421,19 +435,55 @@ void BaseGuiPlus::aboutToExitCompactMode() {
 
 #if DOCK_PLAYLIST
 void BaseGuiPlus::showPlaylist(bool b) {
+	qDebug("BaseGuiPlus::showPlaylist: %d", b);
+	qDebug("BaseGuiPlus::showPlaylist (before): playlist visible: %d", playlistdock->isVisible());
+	qDebug("BaseGuiPlus::showPlaylist (before): playlist position: %d, %d", playlistdock->pos().x(), playlistdock->pos().y());
+	qDebug("BaseGuiPlus::showPlaylist (before): playlist size: %d x %d", playlistdock->size().width(), playlistdock->size().height());
+
 	if ( !b ) {
 		playlistdock->hide();
 	} else {
 		exitFullscreenIfNeeded();
 		playlistdock->show();
+
+		// Check if playlist is outside of the screen
+		if (playlistdock->isFloating()) {
+			if (!DesktopInfo::isInsideScreen(playlistdock)) {
+				qWarning("BaseGuiPlus::showPlaylist: playlist is outside of the screen");
+				playlistdock->move(0,0);
+			}
+		}
 	}
 	//updateWidgets();
+
+	qDebug("BaseGuiPlus::showPlaylist (after): playlist visible: %d", playlistdock->isVisible());
+	qDebug("BaseGuiPlus::showPlaylist (after): playlist position: %d, %d", playlistdock->pos().x(), playlistdock->pos().y());
+	qDebug("BaseGuiPlus::showPlaylist (after): playlist size: %d x %d", playlistdock->size().width(), playlistdock->size().height());
+
 }
 
 void BaseGuiPlus::playlistClosed() {
 	showPlaylistAct->setChecked(false);
 }
 
+#if !USE_DOCK_TOPLEVEL_EVENT
+void BaseGuiPlus::dockVisibilityChanged(bool visible) {
+	qDebug("BaseGuiPlus::dockVisibilityChanged: %d", visible);
+
+	if (!playlistdock->isFloating()) {
+		if (!visible) shrinkWindow(); else stretchWindow();
+	}
+}
+
+#else
+
+void BaseGuiPlus::dockTopLevelChanged(bool floating) {
+	qDebug("BaseGuiPlus::dockTopLevelChanged: %d", floating);
+
+	if (floating) shrinkWindow(); else stretchWindow();
+}
+#endif
+
 void BaseGuiPlus::stretchWindow() {
 	qDebug("BaseGuiPlus::stretchWindow");
 	if ((ignore_playlist_events) || (pref->resize_method!=Preferences::Always)) return;
@@ -499,12 +549,21 @@ void BaseGuiPlus::shrinkWindow() {
 // Convenience functions intended for other GUI's
 TimeSliderAction * BaseGuiPlus::createTimeSliderAction(QWidget * parent) {
 	TimeSliderAction * timeslider_action = new TimeSliderAction( parent );
+	timeslider_action->setObjectName("timeslider_action");
+
+#ifdef SEEKBAR_RESOLUTION
+	connect( timeslider_action, SIGNAL( posChanged(int) ), 
+             core, SLOT(goToPosition(int)) );
+	connect( core, SIGNAL(positionChanged(int)), 
+             timeslider_action, SLOT(setPos(int)) );
+#else
 	connect( timeslider_action, SIGNAL( posChanged(int) ), 
              core, SLOT(goToPos(int)) );
-	connect( timeslider_action, SIGNAL( draggingPos(int) ), 
-             this, SLOT(displayGotoTime(int)) );
 	connect( core, SIGNAL(posChanged(int)), 
              timeslider_action, SLOT(setPos(int)) );
+#endif
+	connect( timeslider_action, SIGNAL( draggingPos(int) ), 
+             this, SLOT(displayGotoTime(int)) );
 #if ENABLE_DELAYED_DRAGGING
 	timeslider_action->setDragDelay( pref->time_slider_drag_delay );
 
@@ -519,6 +578,8 @@ TimeSliderAction * BaseGuiPlus::createTimeSliderAction(QWidget * parent) {
 
 VolumeSliderAction * BaseGuiPlus::createVolumeSliderAction(QWidget * parent) {
 	VolumeSliderAction * volumeslider_action = new VolumeSliderAction(parent);
+	volumeslider_action->setObjectName("volumeslider_action");
+
 	connect( volumeslider_action, SIGNAL( valueChanged(int) ), 
              core, SLOT( setVolume(int) ) );
 	connect( core, SIGNAL(volumeChanged(int)),
