@@ -74,6 +74,12 @@ protected slots:
 	virtual void showPlaylist(bool b);
 	void playlistClosed();
 
+#if !USE_DOCK_TOPLEVEL_EVENT
+	void dockVisibilityChanged(bool visible);
+#else
+	void dockTopLevelChanged(bool floating);
+#endif
+
 	void stretchWindow();
 	void shrinkWindow();
 #endif
