@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,15 +20,28 @@
 #define _CORE_H_
 
 #include <QObject>
-
+#include <QProcess> // For QProcess::ProcessError
 #include "mediadata.h"
 #include "mediasettings.h"
+#include "mplayerprocess.h"
+#include "config.h"
 
+#define NEW_SETTINGS_MANAGEMENT 1
+
+#ifndef NO_USE_INI_FILES
+#if NEW_SETTINGS_MANAGEMENT
+class FileSettingsBase;
+#endif
+#endif
 
 class MplayerProcess;
 class MplayerWindow;
 class QSettings;
 
+#ifdef Q_OS_WIN
+class WinScreenSaver;
+#endif
+
 class Core : public QObject
 {
     Q_OBJECT
@@ -42,8 +55,6 @@ public:
     MediaData mdat;
 	MediaSettings mset;
 
-    QString mplayer_log;
-
 	//! Return the current state
 	State state() { return _state; };
 
@@ -73,6 +84,10 @@ public slots:
 	void loadSub(const QString & sub);
 	void unloadSub();
 
+	//! Forces to use the specified subtitle file. It's not loaded immediately but stored
+	//! and will be used for the next video. After that the variable is cleared.  
+	void setInitialSubtitle(const QString & subtitle_file) { initial_subtitle = subtitle_file; };
+
 	void loadAudioFile(const QString & audiofile);
 	void unloadAudioFile();
 
@@ -87,8 +102,15 @@ public slots:
 	//! Public restart, for the GUI.
 	void restart();
 
+	//! Reopens the file (no restart)
+	void reload();
+
+#ifdef SEEKBAR_RESOLUTION
+    void goToPosition( int value );
+#else
     void goToPos( int perc );
-    /*void goToSec( double sec );*/
+#endif
+    void goToSec( double sec );
 
 	void toggleRepeat();
 	void toggleRepeat(bool b);
@@ -96,6 +118,9 @@ public slots:
 	void toggleFlip();
 	void toggleFlip(bool b);
 
+	void toggleMirror();
+	void toggleMirror(bool b);
+
 	// Audio filters
 	void toggleKaraoke();
 	void toggleKaraoke(bool b);
@@ -119,6 +144,10 @@ public slots:
 	void togglePostprocessing();
 	void togglePostprocessing(bool b);
 	void changeDenoise(int);
+#if NEW_ASPECT_CODE
+	void changeLetterbox(bool);
+#endif
+	void changeUpscale(bool);
 
 	void seek(int secs);
 	void sforward(); 	// + 10 seconds
@@ -133,8 +162,12 @@ public slots:
 	void wheelDown();
 
 	void setSpeed( double value );
-	void incSpeed();
-	void decSpeed();
+	void incSpeed10();	//!< Inc speed 10%
+	void decSpeed10();	//!< Dec speed 10%
+	void incSpeed4();	//!< Inc speed 4%
+	void decSpeed4();	//!< Dec speed 4%
+	void incSpeed1();	//!< Inc speed 1%
+	void decSpeed1();	//!< Dec speed 1%
 	void doubleSpeed();
 	void halveSpeed();
 	void normalSpeed();
@@ -171,7 +204,7 @@ public slots:
 	void incSubPos();
 	void decSubPos();
 
-	void changeSubScale(int value);
+	void changeSubScale(double value);
 	void incSubScale();
 	void decSubScale();
 
@@ -180,17 +213,38 @@ public slots:
 	//! Select previous line in subtitle file
 	void decSubStep();
 
+	//! Audio equalizer
+	void setAudioEqualizer(AudioEqualizerList values, bool restart = false);
+	void setAudioAudioEqualizerRestart(AudioEqualizerList values) { setAudioEqualizer(values, true); };
+	void updateAudioEqualizer();
+
+	void setAudioEq0(int value);
+	void setAudioEq1(int value);
+	void setAudioEq2(int value);
+	void setAudioEq3(int value);
+	void setAudioEq4(int value);
+	void setAudioEq5(int value);
+	void setAudioEq6(int value);
+	void setAudioEq7(int value);
+	void setAudioEq8(int value);
+	void setAudioEq9(int value);
+
 	void changeDeinterlace(int);
     void changeSubtitle(int);
 	void nextSubtitle();
-	void changeAudio(int);
+	void changeAudio(int ID, bool allow_restart = true);
 	void nextAudio();
+	void changeVideo(int ID, bool allow_restart = true);
+	void nextVideo();
 	void changeTitle(int);
 	void changeChapter(int);
 	void prevChapter();
 	void nextChapter();
 	void changeAngle(int);
 	void changeAspectRatio(int);
+#if NEW_ASPECT_CODE
+	void nextAspectRatio();
+#endif
 	void changeOSD(int);
 	void nextOSD();
 
@@ -198,15 +252,57 @@ public slots:
 	void toggleDoubleSize();
 	void changePanscan(double); // Zoom on mplayerwindow
 
+	void changeRotate(int r);
+
+#if USE_ADAPTER
+	void changeAdapter(int n);
+#endif
+
 	void incPanscan();
 	void decPanscan();
 	void resetPanscan();
+	void autoPanscan();
+	void autoPanscanFromLetterbox(double video_aspect);
+	void autoPanscanFor169();
+	void autoPanscanFor235();
 
 	void changeUseAss(bool);
+	void toggleClosedCaption(bool);
+	void toggleForcedSubsOnly(bool);
+
+	void visualizeMotionVectors(bool);
+
+#if DVDNAV_SUPPORT
+	// dvdnav buttons
+	void dvdnavUp();
+	void dvdnavDown();
+	void dvdnavLeft();
+	void dvdnavRight();
+	void dvdnavMenu();
+	void dvdnavSelect();
+	void dvdnavPrev();
+	void dvdnavMouse();
+#endif
 
     // Pass a command to mplayer by stdin:
     void tellmp(const QString & command);
 
+public:
+	//! Returns the number of the first chapter in 
+	//! files. In some versions of mplayer is 0, in others 1
+	static int firstChapter();
+#if !GENERIC_CHAPTER_SUPPORT
+	static int dvdFirstChapter();
+#endif
+
+#ifndef NO_USE_INI_FILES
+	void changeFileSettingsMethod(QString method);
+#endif
+
+protected:
+	//! Returns the prefix to keep pausing on slave commands
+	QString pausing_prefix();
+
 protected slots:
     void changeCurrentSec(double sec);
     void changePause();
@@ -220,16 +316,30 @@ protected slots:
     void processFinished();
 	void fileReachedEnd();
     
-	void updateLog(QString line);
-
 	void displayMessage(QString text);
 	void displayScreenshotName(QString filename);
+	void displayUpdatingFontCache();
 
 	void streamTitleAndUrlChanged(QString,QString);
-	void autosaveMplayerLog();
 	
 	void watchState(Core::State state);
 
+	//! Called when a video has just started to play.
+	//! This function checks if the codec of video is ffh264 and if
+	//! the resolution is HD
+	void checkIfVideoIsHD();
+
+#if DELAYED_AUDIO_SETUP_ON_STARTUP
+	void initAudioTrack();
+#endif
+#if NOTIFY_AUDIO_CHANGES
+	void initAudioTrack(const Tracks &);
+#endif
+#if NOTIFY_SUB_CHANGES
+	void initSubtitleTrack(const SubTracks &);
+	void setSubtitleTrackAgain(const SubTracks &);
+#endif
+
 protected:
 	void playNewFile(QString file, int seek=-1);
 	void restartPlay();
@@ -239,13 +349,20 @@ protected:
     void startMplayer(QString file, double seek = -1 );
 	void stopMplayer();
 
+#ifndef NO_USE_INI_FILES
+	#if !NEW_SETTINGS_MANAGEMENT
 	bool checkHaveSettingsSaved(QString filename);
-	void saveMediaInfo();
 	void loadMediaInfo(QString filename);
+	#endif
+	void saveMediaInfo();
+#endif
 
     void initializeMenus();
 	void updateWidgets();
 
+	//! Returns true if changing the subscale requires to restart mplayer
+	bool subscale_need_restart();
+
 signals:
 	void aboutToStartPlaying(); // Signal emited just before to start mplayer
 	void mediaLoaded();
@@ -257,18 +374,49 @@ signals:
 	void showMessage(QString text);
 	void menusNeedInitialize();
 	void widgetsNeedUpdate();
-	void equalizerNeedsUpdate();
+	void videoEqualizerNeedsUpdate();
+	void audioEqualizerNeedsUpdate();
 	void showTime(double sec);
+#ifdef SEEKBAR_RESOLUTION
+	void positionChanged(int); // To connect a slider
+#else
+	void posChanged(int); // To connect a slider
+#endif
 	void showFrame(int frame);
 	void needResize(int w, int h);
-	void mplayerFinishedWithError(int);
 	void noVideo();
 	void volumeChanged(int);
+#if NOTIFY_SUB_CHANGES
+	void audioTracksChanged();
+#endif
+
+	//! MPlayer started but finished with exit code != 0
+	void mplayerFinishedWithError(int exitCode);
+
+	//! MPlayer didn't started or crashed
+	void mplayerFailed(QProcess::ProcessError error);
+
+	// Resend signal from mplayerprocess:
+	void failedToParseMplayerVersion(QString line_with_mplayer_version);
+
+	//! A new line from the mplayer output is available
+	void logLineAvailable(QString);
 
 protected:
     MplayerProcess * proc;
     MplayerWindow * mplayerwindow;
+
+#ifndef NO_USE_INI_FILES
+	#if NEW_SETTINGS_MANAGEMENT
+	FileSettingsBase * file_settings;
+	#else
 	QSettings * file_settings;
+	#endif
+#endif
+
+#ifdef Q_OS_WIN
+	WinScreenSaver * win_screensaver;
+#endif
     
 private:
 	// Some variables to proper restart
@@ -278,6 +426,8 @@ private:
 	bool just_unloaded_external_subs;
 	State _state;
 	bool change_volume_after_unpause;
+
+	QString initial_subtitle;
 };
     
 #endif
