@@ -23,7 +23,6 @@
 #include "baseguiplus.h"
 #include <QPoint>
 
-class QLabel;
 class QToolBar;
 class QPushButton;
 class QResizeEvent;
@@ -32,7 +31,7 @@ class QMenu;
 class TimeSliderAction;
 class VolumeSliderAction;
 class FloatingWidget;
-class QLabel;
+class TimeLabelAction;
 
 #if MINI_ARROW_BUTTONS
 class SeekingButton;
@@ -46,6 +45,10 @@ public:
 	DefaultGui( QWidget* parent = 0, Qt::WindowFlags flags = 0 );
 	~DefaultGui();
 
+#if USE_MINIMUMSIZE
+	virtual QSize minimumSizeHint () const;
+#endif
+
 public slots:
 	//virtual void showPlaylist(bool b);
 
@@ -109,7 +112,7 @@ protected:
 #endif
 
 	FloatingWidget * floating_control;
-	QLabel * time_label;
+	TimeLabelAction * time_label_action;
 
 	QMenu * toolbar_menu;
 
@@ -119,10 +122,6 @@ protected:
 	bool fullscreen_toolbar2_was_visible;
 	bool compact_toolbar1_was_visible;
 	bool compact_toolbar2_was_visible;
-
-	// Properties to save
-	int floating_control_width; // Percentage of screen
-	bool floating_control_animated;
 };
 
 #endif
