@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,9 @@ class DesktopInfo
 public:
 	static QSize desktop_size(QWidget *w);
 	static double desktop_aspectRatio(QWidget *w);
+
+	//! Returns true if the widget is inside the current screen
+	static bool isInsideScreen(QWidget *w);
 };
 
 #endif
