@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,6 +44,10 @@ public:
 	const QPixmap * icon() const;
 	QString label() const;
 
+	QSlider * sliderWidget() { return _slider; };
+	VerticalText * labelWidget() { return _label; };
+	QLabel * iconWidget() { return _icon; };
+
 signals:
 	void valueChanged(int);
 
