@@ -218,7 +218,7 @@ void FilePropertiesDialog::changeEvent(QEvent *e) {
 	if (e->type() == QEvent::LanguageChange) {
 		retranslateStrings();
 	} else {
-		QWidget::changeEvent(e);
+		QDialog::changeEvent(e);
 	}
 }
 
