@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,8 +23,7 @@
 
 FloatingWidget::FloatingWidget( QWidget * parent )
 	: QWidget( parent, Qt::Window | Qt::FramelessWindowHint |
-                       Qt::WindowStaysOnTopHint |
-                       Qt::X11BypassWindowManagerHint )
+                       Qt::WindowStaysOnTopHint )
 {
 	setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Minimum );
 
@@ -38,15 +37,41 @@ FloatingWidget::FloatingWidget( QWidget * parent )
 
 	setLayout(layout);
 
+	_margin = 0;
 	_animated = false;
 	animation_timer = new QTimer(this);
 	animation_timer->setInterval(2);
 	connect( animation_timer, SIGNAL(timeout()), this, SLOT(animate()) );
+
+	connect( &auto_hide_timer, SIGNAL(timeout()), 
+             this, SLOT(checkUnderMouse()) );
+	setAutoHide(true);
 }
 
 FloatingWidget::~FloatingWidget() {
 }
 
+#ifndef Q_OS_WIN
+void FloatingWidget::setBypassWindowManager(bool b) {
+	if (b) {
+		setWindowFlags(windowFlags() | Qt::X11BypassWindowManagerHint);
+	}
+	else {
+		setWindowFlags(windowFlags() & ~Qt::X11BypassWindowManagerHint);
+	}
+}
+#endif
+
+void FloatingWidget::setAutoHide(bool b) { 
+	auto_hide = b;
+
+	if (b) 
+		auto_hide_timer.start(5000);
+	else
+		auto_hide_timer.stop();
+}
+
+
 void FloatingWidget::showOver(QWidget * widget, int size, Place place) {
 	qDebug("FloatingWidget::showOver");
 
@@ -59,9 +84,9 @@ void FloatingWidget::showOver(QWidget * widget, int size, Place place) {
 	int x = (widget->width() - width() ) / 2;
 	int y;
 	if (place == Top) 
-		y = 0;
+		y = 0 + _margin;
 	else
-		y = widget->height() - height();
+		y = widget->height() - height() - _margin;
 
 	QPoint p = widget->mapToGlobal(QPoint(x, y));
 
@@ -103,4 +128,11 @@ void FloatingWidget::animate() {
 	}
 }
 
+void FloatingWidget::checkUnderMouse() {
+	if (auto_hide) {
+		//qDebug("FloatingWidget::checkUnderMouse");
+		if ((isVisible()) && (!underMouse())) hide();
+	}
+}
+
 #include "moc_floatingwidget.cpp"
