@@ -20,6 +20,7 @@
 #define _FLOATING_WIDGET_H_
 
 #include <QWidget>
+#include <QTimer>
 
 class QToolBar;
 
@@ -42,15 +43,23 @@ public:
 	QToolBar * toolbar() { return tb; };
 
 	bool isAnimated() { return _animated; };
+	bool autoHide() { return auto_hide; };
+	int margin() { return _margin; };
 
 public slots:
 	void setAnimated(bool b) { _animated = b; };
+	void setAutoHide(bool b);
+	void setMargin(int margin) { _margin = margin; };
+#ifndef Q_OS_WIN
+	void setBypassWindowManager(bool b);
+#endif
 
 protected:
 	QToolBar * tb;
 
 private slots:
 	void animate();
+	void checkUnderMouse();
 
 private:
 	// Animation variables
@@ -59,6 +68,11 @@ private:
 	int final_y;
 	int current_y;
 	Movement current_movement;
+
+	bool auto_hide;
+	QTimer auto_hide_timer;
+
+	int _margin;
 };
 
 #endif
