@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,61 +18,49 @@
 
 
 #include "global.h"
+#include "preferences.h"
+
+#ifndef MINILIB
+
 #include "constants.h"
 #include <QSettings>
-#include "preferences.h"
 #include "translator.h"
-#include "helper.h"
+#include "paths.h"
 #include <QApplication>
 #include <QFile>
 
-QSettings * settings;
-Preferences * pref;
-Translator * translator;
+QSettings * Global::settings = 0;
+Preferences * Global::pref = 0;
+Translator * Global::translator = 0;
 
+using namespace Global;
 
-void global_init(const QString & ini_path) {
+void Global::global_init(const QString & config_path) {
 	qDebug("global_init");
 
 	// Translator
 	translator = new Translator();
 
 	// settings
-	Helper::setIniPath(ini_path);
-	if (Helper::iniPath().isEmpty()) {
+	if (!config_path.isEmpty()) {
+		Paths::setConfigPath(config_path);
+	}
+
+	if (Paths::iniPath().isEmpty()) {
 		settings = new QSettings(QSettings::IniFormat, QSettings::UserScope,
     	                         QString(COMPANY), QString(PROGRAM) );
 	} else {
-		QString filename = Helper::iniPath() + "/smplayer.ini";
+		QString filename = Paths::iniPath() + "/smplayer.ini";
 		settings = new QSettings( filename, QSettings::IniFormat );
 		qDebug("global_init: config file: '%s'", filename.toUtf8().data());
 
 	}
 
-	/*
-	if (!ini_path.isEmpty()) {
-		QString file = ini_path + "/smplayer.ini";
-		settings = new QSettings( file, QSettings::IniFormat );
-		qDebug("global_init: config file: '%s'", file.toUtf8().data());
-	}
-	else 
-	if (QFile::exists(Helper::appHomePath())) {
-		QString file = Helper::appHomePath() + "/smplayer.ini";
-		settings = new QSettings( file, QSettings::IniFormat );
-		qDebug("global_init: config file: '%s'", file.toUtf8().data());
-	}
-	else
-	{
-		settings = new QSettings(QSettings::IniFormat, QSettings::UserScope,
-    	                         QString(COMPANY), QString(PROGRAM) );
-	}
-	*/
-
 	// Preferences
 	pref = new Preferences();
 }
 
-void global_end() {
+void Global::global_end() {
 	qDebug("global_end");
 
 	// delete
@@ -82,3 +70,27 @@ void global_end() {
 	delete settings;
 	delete translator;
 }
+
+#else
+
+Preferences * Global::pref = 0;
+
+using namespace Global;
+
+void Global::global_init() {
+	qDebug("global_init");
+
+	// Preferences
+	pref = new Preferences();
+}
+
+void Global::global_end() {
+	qDebug("global_end");
+
+	// delete
+	delete pref;
+	pref = 0;
+}
+
+#endif // MINILIB
+
