@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,23 +24,43 @@
 
 // Some global objects
 
+#ifndef MINILIB
+
 class QSettings;
 class Preferences;
 class Translator;
 
+namespace Global {
 
-// Read and store application settings
-extern QSettings * settings;
+	//! Read and store application settings
+	extern QSettings * settings;
 
-// Prefences
-extern Preferences * pref;
+	//! Prefences
+	extern Preferences * pref;
 
-// Translator (for changing language)
-extern Translator * translator;
+	//! Translator (for changing language)
+	extern Translator * translator;
 
 
-void global_init(const QString & ini_path);
-void global_end();
+	void global_init(const QString & config_path);
+	void global_end();
+
+};
+
+#else
+
+class Preferences;
+
+namespace Global {
+	//! Prefences
+	extern Preferences * pref;
+
+	void global_init();
+	void global_end();
+
+};
+
+#endif // MINILIB
 
 #endif
 
