@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,62 +22,32 @@
 
 #include <QString>
 #include <QStringList>
+#include "audioequalizerlist.h"
 
-class QWidget;
-class QColor;
+#ifdef Q_OS_WIN
+#include "config.h"
+#endif
+
+class Helper {
 
-class Helper 
-{
 public:
 
-	static void setAppPath(QString path);
-	static QString appPath();
-
-	static QString dataPath();
-	static QString translationPath();
-	static QString docPath();
-	static QString confPath();
-	static QString themesPath();
-	static QString shortcutsPath();
-	static QString qtTranslationPath();
-
-	//! Return the user's home
-	static QString appHomePath();
-
-	static void setIniPath(QString path);
-	static QString iniPath();
-
-
 	// Format a time (hh:mm:ss)
 	static QString formatTime(int secs);
 
 	static QString timeForJumps(int secs);
 
-	// Give a name for config (group name) based on filename
-	static QString filenameForPref(const QString & filename);
-
 	// Give a name for config (group name) based on dvd id
-	static QString dvdForPref(const QString & dvd_id, int title);
+	/* static QString dvdForPref(const QString & dvd_id, int title); */
 
-	//! Adds a line to the log
-	static void addLog(QString s);
-
-	//! Returns the log (the debugging messages)
-	static QString log();
+#ifdef Q_OS_WIN
+	static QString shortPathName(QString long_path);
 
 	//! Enable or disables the screensaver
-	static void setScreensaverEnabled(bool b);
+	/* static void setScreensaverEnabled(bool b); */
+#endif
 
-	/* static void msleep(int ms); */
-
-	static QString colorToRGBA(unsigned int color);
-	static QString colorToRGB(unsigned int color);
-
-	//! Changes the foreground color of the specified widget
-	static void setForegroundColor(QWidget * w, const QColor & color);
-
-	//! Changes the background color of the specified widget
-	static void setBackgroundColor(QWidget * w, const QColor & color);
+	static void msleep(int ms);
 
 	//! Change filenames like "C:/Program Files/" to "C:\Program Files\"
 	static QString changeSlashes(QString filename);
@@ -87,16 +57,15 @@ public:
 
 	static bool directoryContainsDVD(QString directory);
 
-/*
-#ifdef Q_OS_WIN
-	static QString mplayer_intermediate(QString mplayer_bin);
-#endif
-*/
+	//! Returns an int with the version number of Qt at run-time.
+    //! If version is 4.3.2 it returns 40302.
+	static int qtVersion();
 
-private:
-	static QString logs;
-	static QString app_path;
-	static QString ini_path;
+	//! Returns a string to be passed to mplayer with the audio equalizer
+	//! values.
+	static QString equalizerListToString(AudioEqualizerList values);
+
+	static QStringList searchForConsecutiveFiles(const QString & initial_file);
 };
 
 #endif
