@@ -23,32 +23,56 @@ InputURL::InputURL( QWidget* parent, Qt::WindowFlags f )
 	: QDialog(parent, f)
 {
 	setupUi(this);
+
 	url_icon->setPixmap( Images::icon("url_big") );
 	url_edit->setFocus();
 
 	playlist_check->setWhatsThis( 
 		tr("If this option is checked, the URL will be treated as a playlist: "
         "it will be opened as text and will play the URLs in it.") );
+
+	connect(url_edit, SIGNAL(currentIndexChanged(int)), this, SLOT(indexChanged()));
+	connect(playlist_check, SIGNAL(stateChanged(int)), this, SLOT(playlistChanged(int)));
 }
 
 InputURL::~InputURL() {
 }
 
-void InputURL::setURL(QString url) {
-	url_edit->setText(url);
-	url_edit->selectAll();
+void InputURL::setURL(QString url, bool is_playlist) {
+	url_edit->addItem(url, is_playlist);
 }
 
 QString InputURL::url() {
-	return url_edit->text();
+	return url_edit->currentText();
 }
 
 void InputURL::setPlaylist(bool b) {
 	playlist_check->setChecked(b);
+	/*
+	int pos = url_edit->currentIndex();
+	url_edit->setItemData(pos, b);
+	*/
 }
 
 bool InputURL::isPlaylist() {
 	return playlist_check->isChecked();
 }
 
+void InputURL::indexChanged(void) {
+	int pos = url_edit->currentIndex();
+	if (url_edit->itemText(pos) == url_edit->currentText()) {
+		playlist_check->setChecked( url_edit->itemData(pos).toBool() );
+	}
+}
+
+void InputURL::playlistChanged(int state) {
+	/*
+	int pos = url_edit->currentIndex();
+	if (url_edit->itemText(pos) == url_edit->currentText()) {
+		bool is_playlist = (state == Qt::Checked);
+		url_edit->setItemIcon( pos, is_playlist ? Images::icon("playlist") : QIcon() );
+	}
+	*/
+}
+
 #include "moc_inputurl.cpp"
