@@ -30,11 +30,15 @@ public:
 	InputURL( QWidget* parent = 0, Qt::WindowFlags f = 0 );
 	~InputURL();
 
-	void setURL(QString url);
+	void setURL(QString url, bool is_playlist);
 	QString url();
 
 	void setPlaylist(bool b);
 	bool isPlaylist();
+
+protected slots:
+	void indexChanged();
+	void playlistChanged(int);
 };
 
 #endif
