@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include "ui_logwindowbase.h"
 
+class QTextEdit;
+
 class LogWindow : public QWidget, public Ui::LogWindowBase
 {
 	Q_OBJECT
@@ -32,6 +34,16 @@ public:
 	void setText(QString log);
 	QString text();
 
+	void setHtml(QString text);
+	QString html();
+
+	void clear();
+
+	void appendText(QString text);
+	void appendHtml(QString text);
+
+	/* QTextEdit * editor(); */
+
 protected:
 	virtual void retranslateStrings();
 	virtual void changeEvent ( QEvent * event ) ;
