@@ -23,6 +23,7 @@
 #include "smplayer.h"
 #include "global.h"
 #include "helper.h"
+#include "paths.h"
 
 #include <stdio.h>
 
@@ -39,7 +40,12 @@
 
 using namespace Global;
 
+BaseGui * basegui_instance = 0;
+
 void myMessageOutput( QtMsgType type, const char *msg ) {
+	static QStringList saved_lines;
+	static QString orig_line;
+	static QString line2;
 	static QRegExp rx_log;
 
 	if (pref) {
@@ -49,37 +55,56 @@ void myMessageOutput( QtMsgType type, const char *msg ) {
 		rx_log.setPattern(".*");
 	}
 
-	QString line = "["+ QTime::currentTime().toString() + "] " + 
-                   QString::fromUtf8(msg);
+	line2.clear();
+
+	orig_line = QString::fromUtf8(msg);
 
 	switch ( type ) {
 		case QtDebugMsg:
-			if (rx_log.indexIn(line) > -1) {
+			if (rx_log.indexIn(orig_line) > -1) {
 				#ifndef NO_DEBUG_ON_CONSOLE
-				fprintf( stderr, "Debug: %s\n", line.toLocal8Bit().data() );
+				fprintf( stderr, "Debug: %s\n", orig_line.toLocal8Bit().data() );
 				#endif
-				Helper::addLog( line );
+				line2 = orig_line;
 			}
 			break;
 		case QtWarningMsg:
 			#ifndef NO_DEBUG_ON_CONSOLE
-			fprintf( stderr, "Warning: %s\n", line.toLocal8Bit().data() );
+			fprintf( stderr, "Warning: %s\n", orig_line.toLocal8Bit().data() );
 			#endif
-			Helper::addLog( "WARNING: " + line );
+			line2 = "WARNING: " + orig_line;
 			break;
 		case QtFatalMsg:
 			#ifndef NO_DEBUG_ON_CONSOLE
-			fprintf( stderr, "Fatal: %s\n", line.toLocal8Bit().data() );
+			fprintf( stderr, "Fatal: %s\n", orig_line.toLocal8Bit().data() );
 			#endif
-			Helper::addLog( "FATAL: " + line );
+			line2 = "FATAL: " + orig_line;
 			abort();                    // deliberately core dump
 		case QtCriticalMsg:
 			#ifndef NO_DEBUG_ON_CONSOLE
-			fprintf( stderr, "Critical: %s\n", line.toLocal8Bit().data() );
+			fprintf( stderr, "Critical: %s\n", orig_line.toLocal8Bit().data() );
 			#endif
-			Helper::addLog( "CRITICAL: " + line );
+			line2 = "CRITICAL: " + orig_line;
 			break;
 	}
+
+	if (line2.isEmpty()) return;
+
+	line2 = "["+ QTime::currentTime().toString() +"] "+ line2;
+
+	if (basegui_instance) {
+		if (!saved_lines.isEmpty()) {
+			// Send saved lines first
+			for (int n=0; n < saved_lines.count(); n++) {
+				basegui_instance->recordSmplayerLog(saved_lines[n]);
+			}
+			saved_lines.clear();
+		}
+		basegui_instance->recordSmplayerLog(line2);
+	} else {
+		// GUI is not created yet, save lines for later
+		saved_lines.append(line2);
+	}
 }
 
 #if USE_LOCKS
@@ -112,28 +137,45 @@ void remove_lock(QString lock_file) {
 #endif
 #endif
 
+class MyApplication : public QApplication
+{
+public:
+	MyApplication ( int & argc, char ** argv ) : QApplication(argc, argv) {};
+	virtual void commitData ( QSessionManager & /*manager*/ ) {
+		// Nothing to do, let the application to close
+	}
+};
+
 int main( int argc, char ** argv ) 
 {
-	QApplication a( argc, argv );
+	MyApplication a( argc, argv );
 	//a.connect( &a, SIGNAL( lastWindowClosed() ), &a, SLOT( quit() ) );
 
-	// Sets the ini_path
-	QString ini_path;
+	// Sets the config path
+	QString config_path;
+
+#ifdef PORTABLE_APP
+	config_path = a.applicationDirPath();
+#else
+	// If a smplayer.ini exists in the app path, will use that path
+	// for the config file by default
 	if (QFile::exists( a.applicationDirPath() + "/smplayer.ini" ) ) {
-        ini_path = a.applicationDirPath();
-        qDebug("main: using existing %s", QString(ini_path + "/smplayer.ini").toUtf8().data());
-    }
+		config_path = a.applicationDirPath();
+		qDebug("main: using existing %s", QString(config_path + "/smplayer.ini").toUtf8().data());
+	}
+#endif
+
 	QStringList args = a.arguments();
-	int pos = args.indexOf("-ini-path");
+	int pos = args.indexOf("-config-path");
 	if ( pos != -1) {
 		if (pos+1 < args.count()) {
 			pos++;
-			ini_path = args[pos];
+			config_path = args[pos];
 			// Delete from list
 			args.removeAt(pos);
 			args.removeAt(pos-1);
 		} else {
-			printf("Error: expected parameter for -ini-path\r\n");
+			printf("Error: expected parameter for -config-path\r\n");
 			return SMPlayer::ErrorArgument;
 		}
 	}
@@ -142,9 +184,9 @@ int main( int argc, char ** argv )
 
 #if USE_LOCKS
 	//setIniPath will be set later in global_init, but we need it here
-	Helper::setIniPath(ini_path);
+	if (!config_path.isEmpty()) Paths::setConfigPath(config_path);
 
-	QString lock_file = Helper::iniPath() + "/smplayer_init.lock";
+	QString lock_file = Paths::iniPath() + "/smplayer_init.lock";
 	qDebug("main: lock_file: %s", lock_file.toUtf8().data());
 
 #if USE_QXT_LOCKS
@@ -194,7 +236,7 @@ int main( int argc, char ** argv )
 #endif // USE_QXT_LOCKS
 #endif // USE_LOCKS
 
-	SMPlayer * smplayer = new SMPlayer(ini_path);
+	SMPlayer * smplayer = new SMPlayer(config_path);
 	SMPlayer::ExitCode c = smplayer->processArgs( args );
 	if (c != SMPlayer::NoExit) {
 #if USE_LOCKS
@@ -207,6 +249,7 @@ int main( int argc, char ** argv )
 		return c;
 	}
 
+	basegui_instance = smplayer->gui();
 	a.connect(smplayer->gui(), SIGNAL(quitSolicited()), &a, SLOT(quit()));
 	smplayer->start();
 
@@ -220,6 +263,7 @@ int main( int argc, char ** argv )
 
 	int r = a.exec();
 
+	basegui_instance = 0;
 	delete smplayer;
 
 	return r;
