@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,19 +40,20 @@ void MediaData::reset() {
     video_height=0;
     video_aspect= (double) 4/3;
 
+	videos.clear();
 	audios.clear();
 	titles.clear();
 
-#if SUBTITLES_BY_INDEX
 	subs.clear();
-#else
-	subtitles.clear();
-#endif
 
+#if GENERIC_CHAPTER_SUPPORT
+	chapters = 0;
+#else
 	//chapters=0;
 	//angles=0;
 
 	mkv_chapters=0;
+#endif
 
 	initialized=false;
 
@@ -113,14 +114,17 @@ void MediaData::list() {
 
 	qDebug("  initialized: %d", initialized);
 
+#if GENERIC_CHAPTER_SUPPORT
+	qDebug("  chapters: %d", chapters);
+#else
 	qDebug("  mkv_chapters: %d", mkv_chapters);
+#endif
 
 	qDebug("  Subs:");
-#if SUBTITLES_BY_INDEX
 	subs.list();
-#else
-	subtitles.list();
-#endif
+
+	qDebug("  Videos:");
+	videos.list();
 
 	qDebug("  Audios:");
 	audios.list();
