@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,15 +21,14 @@
 
 /* Here we store some volatile info about the file we need to remember */
 
-#include "config.h"
-
-#if SUBTITLES_BY_INDEX
+#include "tracks.h"
 #include "subtracks.h"
-#endif
+#include "titletracks.h"
+#include "config.h"
 
 #include <QString>
 #include <QSettings>
-#include "tracks.h"
+
 
 // Types of media
 
@@ -65,19 +64,20 @@ public:
 
 	void list();
 
-	TrackList audios;
-	TrackList titles; // for DVDs
+	Tracks videos;
+	Tracks audios;
+	TitleTracks titles; // for DVDs
 
-#if SUBTITLES_BY_INDEX
 	SubTracks subs;
-#else
-	TrackList subtitles;
-#endif
 
+#if GENERIC_CHAPTER_SUPPORT
+	int chapters;
+#else
 	//int chapters, angles; // for DVDs
 
 	// Matroshka chapters
 	int mkv_chapters;
+#endif
 
 	// Clip info
 	QString clip_name;
