@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,23 +25,35 @@
 
 #include <QString>
 #include <QSize>
+#include "config.h"
+#include "audioequalizerlist.h"
 
 class QSettings;
 
 class MediaSettings {
 
 public:
-	enum LetterboxType { NoLetterbox = 0, Letterbox_43 = 1, Letterbox_169 = 2 };
 	enum Denoise { NoDenoise = 0, DenoiseNormal = 1, DenoiseSoft = 2 };
+#if NEW_ASPECT_CODE
+	enum Aspect { AspectAuto = 1, Aspect43 = 2, Aspect54 = 3, Aspect149 = 4,
+                  Aspect169 = 5, Aspect1610 = 6, Aspect235 = 7, Aspect11 = 8, 
+                  AspectNone = 0 };
+#else
 	enum Aspect { AspectAuto = 1, Aspect43 = 2, Aspect169 = 3, Aspect235 = 4,
                   Aspect43Letterbox = 5, Aspect43Panscan = 6, 
                   Aspect43To169 = 7, Aspect149 = 8, Aspect1610 = 9, 
                   Aspect54 = 10, Aspect169Letterbox = 11 };
+	enum LetterboxType { NoLetterbox = 0, Letterbox_43 = 1, Letterbox_169 = 2 };
+#endif
 	enum Deinterlace { NoDeinterlace = 0, L5 = 1, Yadif = 2, LB = 3, 
                        Yadif_1 = 4, Kerndeint = 5 };
 	enum AudioChannels { ChDefault = 0, ChStereo = 2, ChSurround = 4, 
                          ChFull51 = 6 };
 	enum StereoMode { Stereo = 0, Left = 1, Right = 2 };
+
+	enum Rotate { NoRotate = -1, Clockwise_flip = 0, Clockwise = 1, 
+                  Counterclockwise = 2, Counterclockwise_flip = 3 };
+
 	enum IDs { NoneSelected = -1000, SubNone = 90000 };
 
 	MediaSettings();
@@ -52,13 +64,13 @@ public:
 	double current_sec;
 	int current_sub_id;
 
+	int current_video_id;
 	int current_audio_id;
 
 	int current_title_id;
 	int current_chapter_id;
 	int current_angle_id;
 
-	LetterboxType letterbox; // Force letterbox
 	int aspect_ratio_id;
 
 	//bool fullscreen;
@@ -68,6 +80,8 @@ public:
 
 	int brightness, contrast, gamma, hue, saturation;
 
+	AudioEqualizerList audio_equalizer;
+
 	QString external_subtitles;
 	QString external_audio; // external audio file
 
@@ -76,13 +90,20 @@ public:
 
 	// Subtitles position (0-100)
 	int sub_pos;
-	int sub_scale;
+	double sub_scale;
+	double sub_scale_ass;
 
 	double speed; // Speed of playback: 1.0 = normal speed
 
 	int current_deinterlacer;
+
+#if NEW_ASPECT_CODE
+	bool add_letterbox;
+#else
+	LetterboxType letterbox; // Force letterbox
 	QString panscan_filter;
 	QString crop_43to169_filter;
+#endif
 
 	// Filters in menu
 	bool phase_filter;
@@ -91,6 +112,7 @@ public:
 	bool dering_filter;
 	bool noise_filter;
 	bool postprocessing_filter;
+	bool upscaling_filter; //!< Software scaling
 
 	bool karaoke_filter;
 	bool extrastereo_filter;
@@ -101,13 +123,18 @@ public:
 
 	double panscan_factor; // mplayerwindow zoom
 
+	int rotate;
 	bool flip; //!< Flip image
+	bool mirror; //!< Mirrors the image on the Y axis.
 
 	// This a property of the video and it should be
     // in mediadata, but we have to save it to preserve 
 	// this data among restarts.
 	double starting_time; // Some videos don't start at 0
 
+	//! The codec of the video is ffh264 and it's high definition
+	bool is264andHD;
+
 	// Advanced settings
 	QString forced_demuxer;
 	QString forced_video_codec;
@@ -133,10 +160,18 @@ public:
     int win_height;
     double win_aspect();
 
+#if NEW_ASPECT_CODE
+	//! Returns the aspect as a double. Returns 0 if aspect == AspectNone.
+	double aspectToNum(Aspect aspect);
+	static QString aspectToString(Aspect aspect);
+#endif
 
 	void list();
+
+#ifndef NO_USE_INI_FILES
 	void save(QSettings * set);
 	void load(QSettings * set);
+#endif
 };
 
 #endif
