@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,16 +23,26 @@
 
 #include "global.h"
 #include "preferences.h"
-#include "config.h"
+#include "mplayerversion.h"
+#include "helper.h"
 
+using namespace Global;
 
 MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent) 
 {
+#if NOTIFY_SUB_CHANGES
+	qRegisterMetaType<SubTracks>("SubTracks");
+#endif
+
+#if NOTIFY_AUDIO_CHANGES
+	qRegisterMetaType<Tracks>("Tracks");
+#endif
+
 	connect( this, SIGNAL(lineAvailable(QByteArray)),
 			 this, SLOT(parseLine(QByteArray)) );
 
 	connect( this, SIGNAL(finished(int,QProcess::ExitStatus)), 
-             this, SLOT(processFinished()) );
+             this, SLOT(processFinished(int,QProcess::ExitStatus)) );
 
 	connect( this, SIGNAL(error(QProcess::ProcessError)),
              this, SLOT(gotError(QProcess::ProcessError)) );
@@ -40,41 +50,33 @@ MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent)
 	notified_mplayer_is_running = false;
 	last_sub_id = -1;
 	mplayer_svn = -1; // Not found yet
-
-	init_rx();
 }
 
 MplayerProcess::~MplayerProcess() {
 }
 
-bool MplayerProcess::isMplayerAtLeast(int svn_revision) {
-	qDebug("MplayerProcess::isMplayerAtLeast: comparing %d with %d", svn_revision, mplayer_svn);
-
-	if (mplayer_svn == -1) {
-		qWarning("MplayerProcess::isMplayerAtLeast: no version found!");
-	}
-	else
-	if (mplayer_svn == 0) {
-		qWarning("MplayerProcess::isMplayerAtLeast: version couldn't be parsed!");
-	}
-
-	if (mplayer_svn <= 0) {
-		qWarning("MplayerProcess::isMplayerAtLeast: assuming that the mplayer version is greater than %d", svn_revision);
-		return true;
-	}
-
-	return (mplayer_svn >= svn_revision);
-}
-
 bool MplayerProcess::start() {
-	init_rx(); // Update configurable regular expressions
-
 	md.reset();
 	notified_mplayer_is_running = false;
 	last_sub_id = -1;
 	mplayer_svn = -1; // Not found yet
 	received_end_of_file = false;
 
+#if NOTIFY_SUB_CHANGES
+	subs.clear();
+	subtitle_info_received = false;
+	subtitle_info_changed = false;
+#endif
+
+#if NOTIFY_AUDIO_CHANGES
+	audios.clear();
+	audio_info_changed = false;
+#endif
+
+#if GENERIC_CHAPTER_SUPPORT
+	dvd_current_title = -1;
+#endif
+
 	MyProcess::start();
 	return waitForStarted();
 }
@@ -88,27 +90,30 @@ void MplayerProcess::writeToStdin(QString text) {
 	}
 }
 
-//static QRegExp rx_mplayer_revision("^MPlayer (\\S+)-SVN-r(\\d+)-(.*)");
-static QRegExp rx_mplayer_revision("^MPlayer (.*)-r(\\d+)(.*)");
-static QRegExp rx_mplayer_version("^MPlayer ([a-z,0-9,.]+)-(.*)");
 static QRegExp rx_av("^[AV]: *([0-9,:.-]+)");
 static QRegExp rx_frame("^[AV]:.* (\\d+)\\/.\\d+");// [0-9,.]+");
 static QRegExp rx("^(.*)=(.*)");
+#if !NOTIFY_AUDIO_CHANGES
 static QRegExp rx_audio_mat("^ID_AID_(\\d+)_(LANG|NAME)=(.*)");
+#endif
+static QRegExp rx_video("^ID_VID_(\\d+)_(LANG|NAME)=(.*)");
 static QRegExp rx_title("^ID_DVD_TITLE_(\\d+)_(LENGTH|CHAPTERS|ANGLES)=(.*)");
 static QRegExp rx_winresolution("^VO: \\[(.*)\\] (\\d+)x(\\d+) => (\\d+)x(\\d+)");
 static QRegExp rx_ao("^AO: \\[(.*)\\]");
 static QRegExp rx_paused("^ID_PAUSED");
+#if !CHECK_VIDEO_CODEC_FOR_NO_VIDEO
 static QRegExp rx_novideo("^Video: no video");
+#endif
 static QRegExp rx_cache("^Cache fill:.*");
 static QRegExp rx_create_index("^Generating Index:.*");
 static QRegExp rx_play("^Starting playback...");
 static QRegExp rx_connecting("^Connecting to .*");
 static QRegExp rx_resolving("^Resolving .*");
 static QRegExp rx_screenshot("^\\*\\*\\* screenshot '(.*)'");
-static QRegExp rx_endoffile("^Exiting... \\(End of file\\)");
+static QRegExp rx_endoffile("^Exiting... \\(End of file\\)|^ID_EXIT=EOF");
 static QRegExp rx_mkvchapters("\\[mkv\\] Chapter (\\d+) from");
 static QRegExp rx_aspect2("^Movie-Aspect is ([0-9,.]+):1");
+static QRegExp rx_fontcache("^\\[ass\\] Updating font cache|^\\[ass\\] Init");
  
 // VCD
 static QRegExp rx_vcd("^ID_VCD_TRACK_(\\d+)_MSF=(.*)");
@@ -118,12 +123,14 @@ static QRegExp rx_cdda("^ID_CDDA_TRACK_(\\d+)_MSF=(.*)");
 
 
 //Subtitles
-#if SUBTITLES_BY_INDEX
 static QRegExp rx_subtitle("^ID_(SUBTITLE|FILE_SUB|VOBSUB)_ID=(\\d+)");
 static QRegExp rx_sid("^ID_(SID|VSID)_(\\d+)_(LANG|NAME)=(.*)");
 static QRegExp rx_subtitle_file("^ID_FILE_SUB_FILENAME=(.*)");
-#else
-static QRegExp rx_subs("^ID_SID_(\\d+)_(LANG|NAME)=(.*)");
+
+// Audio
+#if NOTIFY_AUDIO_CHANGES
+static QRegExp rx_audio("^ID_AUDIO_ID=(\\d+)");
+static QRegExp rx_audio_info("^ID_AID_(\\d+)_(LANG|NAME)=(.*)");
 #endif
 
 //Clip info
@@ -140,16 +147,6 @@ static QRegExp rx_clip_software("^ software: (.*)", Qt::CaseInsensitive);
 
 static QRegExp rx_stream_title("^.* StreamTitle='(.*)';StreamUrl='(.*)';");
 
-void MplayerProcess::init_rx() {
-	qDebug("MplayerProcess::init_rx");
-
-	if (!pref->rx_endoffile.isEmpty()) 
-		rx_endoffile.setPattern(pref->rx_endoffile);
-
-	if (!pref->rx_novideo.isEmpty()) 
-		rx_novideo.setPattern(pref->rx_novideo);
-}
-
 
 void MplayerProcess::parseLine(QByteArray ba) {
 	//qDebug("MplayerProcess::parseLine: '%s'", ba.data() );
@@ -157,32 +154,86 @@ void MplayerProcess::parseLine(QByteArray ba) {
 	QString tag;
 	QString value;
 
+#if COLOR_OUTPUT_SUPPORT
+    QString line = Helper::stripColorsTags(QString::fromLocal8Bit(ba));
+#else
+	QString line = QString::fromLocal8Bit(ba);
+#endif
+
 	// Parse A: V: line
 	//qDebug("%s", line.toUtf8().data());
-	if (rx_av.indexIn(ba) > -1) {
+    if (rx_av.indexIn(line) > -1) {
 		double sec = rx_av.cap(1).toDouble();
 		//qDebug("cap(1): '%s'", rx_av.cap(1).toUtf8().data() );
 		//qDebug("sec: %f", sec);
-		
+
+#if NOTIFY_SUB_CHANGES
+		if (notified_mplayer_is_running) {
+			if (subtitle_info_changed) {
+				qDebug("MplayerProcess::parseLine: subtitle_info_changed");
+				subtitle_info_changed = false;
+				subtitle_info_received = false;
+				emit subtitleInfoChanged(subs);
+			}
+			if (subtitle_info_received) {
+				qDebug("MplayerProcess::parseLine: subtitle_info_received");
+				subtitle_info_received = false;
+				emit subtitleInfoReceivedAgain(subs);
+			}
+		}
+#endif
+
+#if NOTIFY_AUDIO_CHANGES
+		if (notified_mplayer_is_running) {
+			if (audio_info_changed) {
+				qDebug("MplayerProcess::parseLine: audio_info_changed");
+				audio_info_changed = false;
+				emit audioInfoChanged(audios);
+			}
+		}
+#endif
+
 		if (!notified_mplayer_is_running) {
 			qDebug("MplayerProcess::parseLine: starting sec: %f", sec);
+#if GENERIC_CHAPTER_SUPPORT
+			if ( (md.chapters <= 0) && (dvd_current_title > 0) && 
+                 (md.titles.find(dvd_current_title) != -1) )
+			{
+				int idx = md.titles.find(dvd_current_title);
+				md.chapters = md.titles.itemAt(idx).chapters();
+				qDebug("MplayerProcess::parseLine: setting chapters to %d", md.chapters);
+			}
+#endif
+
+#if CHECK_VIDEO_CODEC_FOR_NO_VIDEO
+			// Another way to find out if there's no video
+			if (md.video_codec.isEmpty()) {
+				md.novideo = true;
+				emit receivedNoVideo();
+			}
+#endif
+
 			emit receivedStartingTime(sec);
 			emit mplayerFullyLoaded();
+
+			emit receivedCurrentFrame(0); // Ugly hack: set the frame counter to 0
+
 			notified_mplayer_is_running = true;
 		}
 		
 	    emit receivedCurrentSec( sec );
 
 		// Check for frame
-		if (rx_frame.indexIn(ba) > -1) {
+        if (rx_frame.indexIn(line) > -1) {
 			int frame = rx_frame.cap(1).toInt();
 			//qDebug(" frame: %d", frame);
 			emit receivedCurrentFrame(frame);
 		}
 	}
 	else {
-		QString line = QString::fromLocal8Bit( ba );
-		//QString line = QString::fromUtf8( ba );
+		// Emulates mplayer version in Ubuntu:
+		//if (line.startsWith("MPlayer 1.0rc1")) line = "MPlayer 2:1.0~rc1-0ubuntu13.1 (C) 2000-2006 MPlayer Team";
+
 		emit lineAvailable(line);
 
 		// Parse other things
@@ -197,21 +248,22 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		else
 
 		// End of file
-		if (rx_endoffile.indexIn(line) > -1) {
+		if (rx_endoffile.indexIn(line) > -1)  {
 			qDebug("MplayerProcess::parseLine: detected end of file");
+			if (!received_end_of_file) {
+				// In case of playing VCDs or DVDs, maybe the first title
+    	        // is not playable, so the GUI doesn't get the info about
+        	    // available titles. So if we received the end of file
+            	// first let's pretend the file has started so the GUI can have
+	            // the data.
+				if ( !notified_mplayer_is_running) {
+					emit mplayerFullyLoaded();
+				}
 
-			// In case of playing VCDs or DVDs, maybe the first title
-            // is not playable, so the GUI doesn't get the info about
-            // available titles. So if we received the end of file
-            // first let's pretend the file has started so the GUI can have
-            // the data.
-			if ( !notified_mplayer_is_running) {
-				emit mplayerFullyLoaded();
+				//emit receivedEndOfFile();
+				// Send signal once the process is finished, not now!
+				received_end_of_file = true;
 			}
-
-			//emit receivedEndOfFile();
-			// Send signal once the process is finished, not now!
-			received_end_of_file = true;
 		}
 		else
 
@@ -232,6 +284,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		}
 		else
 
+#if !CHECK_VIDEO_CODEC_FOR_NO_VIDEO
 		// No video
 		if (rx_novideo.indexIn(line) > -1) {
 			md.novideo = TRUE;
@@ -239,6 +292,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			//emit mplayerFullyLoaded();
 		}
 		else
+#endif
 
 		// Pause
 		if (rx_paused.indexIn(line) > -1) {
@@ -256,6 +310,60 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			emit receivedStreamTitleAndUrl( s, url );
 		}
 
+#if NOTIFY_SUB_CHANGES
+		// Subtitles
+		if ((rx_subtitle.indexIn(line) > -1) || (rx_sid.indexIn(line) > -1) || (rx_subtitle_file.indexIn(line) > -1)) {
+			int r = subs.parse(line);
+			subtitle_info_received = true;
+			subtitle_info_changed = ((r == SubTracks::SubtitleAdded) || (r == SubTracks::SubtitleChanged));
+		}
+#endif
+
+#if NOTIFY_AUDIO_CHANGES
+		// Audio
+		if (rx_audio.indexIn(line) > -1) {
+			int ID = rx_audio.cap(1).toInt();
+			qDebug("MplayerProcess::parseLine: ID_AUDIO_ID: %d", ID);
+			if (audios.find(ID) == -1) audio_info_changed = true;
+			audios.addID( ID );
+		}
+
+		if (rx_audio_info.indexIn(line) > -1) {
+			int ID = rx_audio_info.cap(1).toInt();
+			QString lang = rx_audio_info.cap(3);
+			QString t = rx_audio_info.cap(2);
+			qDebug("MplayerProcess::parseLine: Audio: ID: %d, Lang: '%s' Type: '%s'", 
+                    ID, lang.toUtf8().data(), t.toUtf8().data());
+
+			int idx = audios.find(ID);
+			if (idx == -1) {
+				qDebug("MplayerProcess::parseLine: audio %d doesn't exist, adding it", ID);
+
+				audio_info_changed = true;
+				if ( t == "NAME" ) 
+					audios.addName(ID, lang);
+				else
+					audios.addLang(ID, lang);
+			} else {
+				qDebug("MplayerProcess::parseLine: audio %d exists, modifing it", ID);
+
+				if (t == "NAME") {
+					//qDebug("MplayerProcess::parseLine: name of audio %d: %s", ID, audios.itemAt(idx).name().toUtf8().constData());
+					if (audios.itemAt(idx).name() != lang) {
+						audio_info_changed = true;
+						audios.addName(ID, lang);
+					}
+				} else {
+					//qDebug("MplayerProcess::parseLine: language of audio %d: %s", ID, audios.itemAt(idx).lang().toUtf8().constData());
+					if (audios.itemAt(idx).lang() != lang) {
+						audio_info_changed = true;
+						audios.addLang(ID, lang);
+					}
+				}
+			}
+		}
+#endif
+
 		// The following things are not sent when the file has started to play
 		// (or if sent, smplayer will ignore anyway...)
 		// So not process anymore, if video is playing to save some time
@@ -263,62 +371,36 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			return;
 		}
 
-		if (mplayer_svn == -1) {
-			if (rx_mplayer_revision.indexIn(line) > -1) {
-				mplayer_svn = rx_mplayer_revision.cap(2).toInt();
-				qDebug("MplayerProcess::parseLine: MPlayer SVN revision found: %d", mplayer_svn);
-			} 
-			else
-			if (rx_mplayer_version.indexIn(line) > -1) {
-				QString version = rx_mplayer_version.cap(1);
-				qDebug("MplayerProcess::parseLine: MPlayer version found: %s", version.toUtf8().data());
-				mplayer_svn = 0;
-				if (version == "1.0rc2") mplayer_svn = 24722;
-				else
-				if (version == "1.0rc1") mplayer_svn = 20372;
-				else qWarning("MplayerProcess::parseLine: unknown MPlayer version");
-
-				qDebug("MplayerProcess::parseLine: MPlayer SVN: %d", mplayer_svn);
+		if ( (mplayer_svn == -1) && (line.startsWith("MPlayer ")) ) {
+			mplayer_svn = MplayerVersion::mplayerVersion(line);
+			qDebug("MplayerProcess::parseLine: MPlayer SVN: %d", mplayer_svn);
+			if (mplayer_svn <= 0) {
+				qWarning("MplayerProcess::parseLine: couldn't parse mplayer version!");
+				emit failedToParseMplayerVersion(line);
 			}
 		}
 
-#if SUBTITLES_BY_INDEX
+#if !NOTIFY_SUB_CHANGES
+		// Subtitles
 		if (rx_subtitle.indexIn(line) > -1) {
-			md.subs.process(line);
+			md.subs.parse(line);
 		}
 		else
 		if (rx_sid.indexIn(line) > -1) {
-			md.subs.process(line);
+			md.subs.parse(line);
 		}
 		else
 		if (rx_subtitle_file.indexIn(line) > -1) {
-			md.subs.process(line);
+			md.subs.parse(line);
 		}
 #endif
-
 		// AO
 		if (rx_ao.indexIn(line) > -1) {
 			emit receivedAO( rx_ao.cap(1) );
 		}
 		else
 
-#if !SUBTITLES_BY_INDEX
-		// Matroska subtitles
-		if (rx_subs.indexIn(line) > -1) {
-			int ID = rx_subs.cap(1).toInt();
-			QString lang = rx_subs.cap(3);
-			QString t = rx_subs.cap(2);
-			qDebug("MplayerProcess::parseLine: Subs: ID: %d, Lang: '%s' Type: '%s'", 
-                    ID, lang.toUtf8().data(), t.toUtf8().data());
-
-			if ( t == "NAME" )
-				md.subtitles.addName(ID, lang);
-			else
-				md.subtitles.addLang(ID, lang);
-		}
-		else
-#endif
-
+#if !NOTIFY_AUDIO_CHANGES
 		// Matroska audio
 		if (rx_audio_mat.indexIn(line) > -1) {
 			int ID = rx_audio_mat.cap(1).toInt();
@@ -333,15 +415,38 @@ void MplayerProcess::parseLine(QByteArray ba) {
 				md.audios.addLang(ID, lang);
 		}
 		else
+#endif
+
+		// Video tracks
+		if (rx_video.indexIn(line) > -1) {
+			int ID = rx_video.cap(1).toInt();
+			QString lang = rx_video.cap(3);
+			QString t = rx_video.cap(2);
+			qDebug("MplayerProcess::parseLine: Video: ID: %d, Lang: '%s' Type: '%s'", 
+                    ID, lang.toUtf8().data(), t.toUtf8().data());
+
+			if ( t == "NAME" ) 
+				md.videos.addName(ID, lang);
+			else
+				md.videos.addLang(ID, lang);
+		}
+		else
 
 		// Matroshka chapters
 		if (rx_mkvchapters.indexIn(line)!=-1) {
 			int c = rx_mkvchapters.cap(1).toInt();
 			qDebug("MplayerProcess::parseLine: mkv chapters: %d", c);
-			if (c > md.mkv_chapters) {
-				md.mkv_chapters = c;
-				qDebug("MplayerProcess::parseLine: mkv_chapters set to: %d", c);
+#if GENERIC_CHAPTER_SUPPORT
+			if ((c+1) > md.chapters) {
+				md.chapters = c+1;
+				qDebug("MplayerProcess::parseLine: chapters set to: %d", md.chapters);
 			}
+#else
+			if ((c+1) > md.mkv_chapters) {
+				md.mkv_chapters = c+1;
+				qDebug("MplayerProcess::parseLine: mkv_chapters set to: %d", md.mkv_chapters);
+			}
+#endif
 		}
 		else
 
@@ -430,9 +535,14 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		else
 
 		// Clip info
+
+		//QString::trimmed() is used for removing leading and trailing whitespaces
+		//Some .mp3 files contain tags with starting and ending whitespaces
+		//Unfortunately MPlayer gives us leading and trailing whitespaces, Winamp for example doesn't show them
+
 		// Name
 		if (rx_clip_name.indexIn(line) > -1) {
-			QString s = rx_clip_name.cap(2);
+			QString s = rx_clip_name.cap(2).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_name: '%s'", s.toUtf8().data());
 			md.clip_name = s;
 		}
@@ -440,7 +550,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Artist
 		if (rx_clip_artist.indexIn(line) > -1) {
-			QString s = rx_clip_artist.cap(1);
+			QString s = rx_clip_artist.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_artist: '%s'", s.toUtf8().data());
 			md.clip_artist = s;
 		}
@@ -448,7 +558,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Author
 		if (rx_clip_author.indexIn(line) > -1) {
-			QString s = rx_clip_author.cap(1);
+			QString s = rx_clip_author.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_author: '%s'", s.toUtf8().data());
 			md.clip_author = s;
 		}
@@ -456,7 +566,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Album
 		if (rx_clip_album.indexIn(line) > -1) {
-			QString s = rx_clip_album.cap(1);
+			QString s = rx_clip_album.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_album: '%s'", s.toUtf8().data());
 			md.clip_album = s;
 		}
@@ -464,7 +574,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Genre
 		if (rx_clip_genre.indexIn(line) > -1) {
-			QString s = rx_clip_genre.cap(1);
+			QString s = rx_clip_genre.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_genre: '%s'", s.toUtf8().data());
 			md.clip_genre = s;
 		}
@@ -472,7 +582,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Date
 		if (rx_clip_date.indexIn(line) > -1) {
-			QString s = rx_clip_date.cap(2);
+			QString s = rx_clip_date.cap(2).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_date: '%s'", s.toUtf8().data());
 			md.clip_date = s;
 		}
@@ -480,7 +590,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Track
 		if (rx_clip_track.indexIn(line) > -1) {
-			QString s = rx_clip_track.cap(1);
+			QString s = rx_clip_track.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_track: '%s'", s.toUtf8().data());
 			md.clip_track = s;
 		}
@@ -488,7 +598,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Copyright
 		if (rx_clip_copyright.indexIn(line) > -1) {
-			QString s = rx_clip_copyright.cap(1);
+			QString s = rx_clip_copyright.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_copyright: '%s'", s.toUtf8().data());
 			md.clip_copyright = s;
 		}
@@ -496,7 +606,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Comment
 		if (rx_clip_comment.indexIn(line) > -1) {
-			QString s = rx_clip_comment.cap(1);
+			QString s = rx_clip_comment.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_comment: '%s'", s.toUtf8().data());
 			md.clip_comment = s;
 		}
@@ -504,12 +614,18 @@ void MplayerProcess::parseLine(QByteArray ba) {
 
 		// Software
 		if (rx_clip_software.indexIn(line) > -1) {
-			QString s = rx_clip_software.cap(1);
+			QString s = rx_clip_software.cap(1).trimmed();
 			qDebug("MplayerProcess::parseLine: clip_software: '%s'", s.toUtf8().data());
 			md.clip_software = s;
 		}
 		else
 
+		if (rx_fontcache.indexIn(line) > -1) {
+			//qDebug("MplayerProcess::parseLine: updating font cache");
+			emit receivedUpdatingFontCache();
+		}
+		else
+
 		// Catch starting message
 		/*
 		pos = rx_play.indexIn(line);
@@ -524,6 +640,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			value = rx.cap(2);
 			//qDebug("MplayerProcess::parseLine: tag: %s, value: %s", tag.toUtf8().data(), value.toUtf8().data());
 
+#if !NOTIFY_AUDIO_CHANGES
 			// Generic audio
 			if (tag == "ID_AUDIO_ID") {
 				int ID = value.toInt();
@@ -531,40 +648,15 @@ void MplayerProcess::parseLine(QByteArray ba) {
 				md.audios.addID( ID );
 			}
 			else
-
-#if !SUBTITLES_BY_INDEX
-			// Generic subtitle
-			if (tag == "ID_SUBTITLE_ID") {
-				int ID = value.toInt();
-				qDebug("MplayerProcess::parseLine: ID_SUBTITLE_ID: %d", ID);
-				md.subtitles.addID( ID );
-			}
-			else
-
-			// Avi subs (srt, sub...)
-			
-			if (tag == "ID_FILE_SUB_ID") {
-				int ID = value.toInt();
-				qDebug("MplayerProcess::parseLine: SUB_ID: %d", ID);
-				md.subtitles.addID( ID );
-				last_sub_id = ID;
-			}
-			else
-			
-			if (tag == "ID_FILE_SUB_FILENAME") {
-				QString name = value;
-				qDebug("MplayerProcess::parseLine: SUB_FILENAME: %s", name.toUtf8().data() );
-				if (last_sub_id != -1) md.subtitles.addFilename( last_sub_id, name );
-				/*
-				if (!md.subtitles.existsFilename(name)) {
-					int new_id = md.subtitles.lastID() + 1;
-					qDebug("MplayerProcess::parseLine: creating new id for file sub: %d", new_id);
-					md.subtitles.addFilename( new_id, value );
-				}
-				*/
-			}
 #endif
 
+			// Video
+			if (tag == "ID_VIDEO_ID") {
+				int ID = value.toInt();
+				qDebug("MplayerProcess::parseLine: ID_VIDEO_ID: %d", ID);
+				md.videos.addID( ID );
+			}
+			else
 			if (tag == "ID_LENGTH") {
 				md.duration = value.toDouble();
 				qDebug("MplayerProcess::parseLine: md.duration set to %f", md.duration);
@@ -633,13 +725,23 @@ void MplayerProcess::parseLine(QByteArray ba) {
 			if (tag == "ID_AUDIO_CODEC") {
 				md.audio_codec = value;
 			}
+#if GENERIC_CHAPTER_SUPPORT
+			else
+			if (tag == "ID_CHAPTERS") {
+				md.chapters = value.toInt();
+			}
+			else
+			if (tag == "ID_DVD_CURRENT_TITLE") {
+				dvd_current_title = value.toInt();
+			}
+#endif
 		}
 	}
 }
 
 // Called when the process is finished
-void MplayerProcess::processFinished() {
-	qDebug("MplayerProcess::processFinished");
+void MplayerProcess::processFinished(int exitCode, QProcess::ExitStatus exitStatus) {
+	qDebug("MplayerProcess::processFinished: exitCode: %d, status: %d", exitCode, (int) exitStatus);
 	// Send this signal before the endoffile one, otherwise
 	// the playlist will start to play next file before all
 	// objects are notified that the process has exited.
