@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,10 @@
 #include <QString>
 #include "myprocess.h"
 #include "mediadata.h"
+#include "config.h"
+
+#define NOTIFY_SUB_CHANGES 1
+#define NOTIFY_AUDIO_CHANGES 1
 
 class QStringList;
 
@@ -38,9 +42,6 @@ public:
 
 	MediaData mediaData() { return md; };
 
-	int mplayerVersion() { return mplayer_svn; };
-	bool isMplayerAtLeast(int svn_revision);
-
 signals:
 	void processExited();
 	void lineAvailable(QString line);
@@ -61,17 +62,29 @@ signals:
 	void receivedConnectingToMessage(QString);
 	void receivedResolvingMessage(QString);
 	void receivedScreenshot(QString);
+	void receivedUpdatingFontCache();
 
 	void receivedStreamTitleAndUrl(QString,QString);
 
+	void failedToParseMplayerVersion(QString line_with_mplayer_version);
+
+#if NOTIFY_SUB_CHANGES
+	//! Emitted if a new subtitle has been added or an old one changed
+	void subtitleInfoChanged(const SubTracks &);
+
+	//! Emitted when subtitle info has been received but there wasn't anything new
+	void subtitleInfoReceivedAgain(const SubTracks &);
+#endif
+#if NOTIFY_AUDIO_CHANGES
+	//! Emitted if a new audio track been added or an old one changed
+    void audioInfoChanged(const Tracks &);
+#endif
+
 protected slots:
 	void parseLine(QByteArray ba);
-	void processFinished();
+	void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
 	void gotError(QProcess::ProcessError);
 
-protected:
-	void init_rx();
-
 private:
 	bool notified_mplayer_is_running;
 	bool received_end_of_file;
@@ -81,6 +94,22 @@ private:
 	int last_sub_id;
 
 	int mplayer_svn;
+
+#if NOTIFY_SUB_CHANGES
+	SubTracks subs;
+
+	bool subtitle_info_received;
+	bool subtitle_info_changed;
+#endif
+
+#if NOTIFY_AUDIO_CHANGES
+	Tracks audios;
+	bool audio_info_changed;
+#endif
+
+#if GENERIC_CHAPTER_SUPPORT
+	int dvd_current_title;
+#endif
 };
 
 
