@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,12 +17,13 @@
 */
 
 #include "mplayerwindow.h"
-#include "constants.h"
-
-#include "images.h"
 #include "global.h"
 #include "desktopinfo.h"
-#include "helper.h"
+#include "colorutils.h"
+
+#ifndef MINILIB
+#include "images.h"
+#endif
 
 #include <QLabel>
 #include <QTimer>
@@ -32,27 +33,34 @@
 #include <QPixmap>
 #include <QPainter>
 
-Screen::Screen(QWidget* parent, Qt::WindowFlags f) 
-#if USE_GL_WIDGET
-	: QGLWidget(parent, 0, f ) 
-#else
-	: QWidget(parent, f ) 
+#if DELAYED_RESIZE
+#include <QTimer>
 #endif
+
+Screen::Screen(QWidget* parent, Qt::WindowFlags f) : QWidget(parent, f ) 
 {
 	setMouseTracking(TRUE);
 	setFocusPolicy( Qt::NoFocus );
 	setMinimumSize( QSize(0,0) );
 
+#if NEW_MOUSE_CHECK_POS
+	mouse_last_position = QPoint(0,0);
+#else
 	cursor_pos = QPoint(0,0);
 	last_cursor_pos = QPoint(0,0);
+#endif
 
 	QTimer *timer = new QTimer(this);
 	connect( timer, SIGNAL(timeout()), this, SLOT(checkMousePos()) );
+#if NEW_MOUSE_CHECK_POS
+	timer->start(500);
+#else
 	timer->start(2000);
+#endif
 
 	// Change attributes
 	setAttribute(Qt::WA_NoSystemBackground);
-	setAttribute(Qt::WA_StaticContents);
+	//setAttribute(Qt::WA_StaticContents);
     //setAttribute( Qt::WA_OpaquePaintEvent );
 	setAttribute(Qt::WA_PaintOnScreen);
 	setAttribute(Qt::WA_PaintUnclipped);
@@ -69,7 +77,19 @@ void Screen::paintEvent( QPaintEvent * e ) {
 	//painter.fillRect( e->rect(), QColor(255,0,0) );
 }
 
+#if NEW_MOUSE_CHECK_POS
+void Screen::checkMousePos() {
+	//qDebug("Screen::checkMousePos");
+	QPoint pos = mapFromGlobal(QCursor::pos());
 
+	if (mouse_last_position != pos) {
+		setCursor(QCursor(Qt::ArrowCursor));
+	} else {
+		setCursor(QCursor(Qt::BlankCursor));
+	}
+	mouse_last_position = pos;
+}
+#else
 void Screen::checkMousePos() {
 	//qDebug("Screen::checkMousePos");
 	
@@ -93,34 +113,37 @@ void Screen::mouseMoveEvent( QMouseEvent * e ) {
 		//qDebug(" showing mouse cursor" );
 		setCursor(QCursor(Qt::ArrowCursor));
 	}
-
-	emit mouseMoved( e->pos() );
 }
+#endif
 
 /* ---------------------------------------------------------------------- */
 
 MplayerLayer::MplayerLayer(QWidget* parent, Qt::WindowFlags f) 
 	: Screen(parent, f) 
 {
-	allow_clearing = true;
+#if REPAINT_BACKGROUND_OPTION
+	repaint_background = true;
+#endif
 	playing = false;
 }
 
 MplayerLayer::~MplayerLayer() {
 }
 
-void MplayerLayer::allowClearingBackground(bool b) {
-	qDebug("MplayerLayer::allowClearingBackground: %d", b);
-	allow_clearing = b;
+#if REPAINT_BACKGROUND_OPTION
+void MplayerLayer::setRepaintBackground(bool b) {
+	qDebug("MplayerLayer::setRepaintBackground: %d", b);
+	repaint_background = b;
 }
 
 void MplayerLayer::paintEvent( QPaintEvent * e ) {
 	//qDebug("MplayerLayer::paintEvent: allow_clearing: %d", allow_clearing);
-	if (allow_clearing || !playing) {
+	if (repaint_background || !playing) {
 		//qDebug("MplayerLayer::paintEvent: painting");
 		Screen::paintEvent(e);
 	}
 }
+#endif
 
 void MplayerLayer::playingStarted() {
 	qDebug("MplayerLayer::playingStarted");
@@ -144,14 +167,19 @@ MplayerWindow::MplayerWindow(QWidget* parent, Qt::WindowFlags f)
 	zoom_factor = 1.0;
 
 	setAutoFillBackground(true);
-	Helper::setBackgroundColor( this, QColor(0,0,0) );
+	ColorUtils::setBackgroundColor( this, QColor(0,0,0) );
 
 	mplayerlayer = new MplayerLayer( this );
 	mplayerlayer->setAutoFillBackground(TRUE);
 
 	logo = new QLabel( mplayerlayer );
 	logo->setAutoFillBackground(TRUE);
-	Helper::setBackgroundColor( logo, QColor(0,0,0) );
+#if QT_VERSION >= 0x040400
+	logo->setAttribute(Qt::WA_NativeWindow); // Otherwise the logo is not visible in Qt 4.4
+#else
+	logo->setAttribute(Qt::WA_PaintOnScreen); // Fixes the problem if compiled with Qt < 4.4
+#endif
+	ColorUtils::setBackgroundColor( logo, QColor(0,0,0) );
 
 	QVBoxLayout * mplayerlayerLayout = new QVBoxLayout( mplayerlayer );
 	mplayerlayerLayout->addWidget( logo, 0, Qt::AlignHCenter | Qt::AlignVCenter );
@@ -162,8 +190,16 @@ MplayerWindow::MplayerWindow(QWidget* parent, Qt::WindowFlags f)
 	setSizePolicy( QSizePolicy::Expanding , QSizePolicy::Expanding );
 	setFocusPolicy( Qt::StrongFocus );
 
-	connect( mplayerlayer, SIGNAL(mouseMoved(QPoint)),
-             this, SLOT(translatePos(QPoint)) );
+	installEventFilter(this);
+	mplayerlayer->installEventFilter(this);
+	//logo->installEventFilter(this);
+
+#if DELAYED_RESIZE
+	resize_timer = new QTimer(this);
+	resize_timer->setSingleShot(true);
+	resize_timer->setInterval(50);
+	connect( resize_timer, SIGNAL(timeout()), this, SLOT(resizeLater()) );
+#endif
 
 	retranslateStrings();
 }
@@ -171,13 +207,17 @@ MplayerWindow::MplayerWindow(QWidget* parent, Qt::WindowFlags f)
 MplayerWindow::~MplayerWindow() {
 }
 
+#if USE_COLORKEY
 void MplayerWindow::setColorKey( QColor c ) {
-	Helper::setBackgroundColor( mplayerlayer, c );
+	ColorUtils::setBackgroundColor( mplayerlayer, c );
 }
+#endif
 
 void MplayerWindow::retranslateStrings() {
 	//qDebug("MplayerWindow::retranslateStrings");
+#ifndef MINILIB
 	logo->setPixmap( Images::icon("background") );
+#endif
 }
 
 void MplayerWindow::showLogo( bool b)
@@ -206,13 +246,26 @@ void MplayerWindow::resizeEvent( QResizeEvent * /* e */)
    /*qDebug("MplayerWindow::resizeEvent: %d, %d",
 	   e->size().width(), e->size().height() );*/
 
+#if !DELAYED_RESIZE
+	offset_x = 0;
+	offset_y = 0;
+
+    updateVideoWindow();
+	setZoom(zoom_factor);
+#else
+	resize_timer->start();
+#endif
+}
+
+#if DELAYED_RESIZE
+void MplayerWindow::resizeLater() {
 	offset_x = 0;
 	offset_y = 0;
 
     updateVideoWindow();
 	setZoom(zoom_factor);
 }
-
+#endif
 
 void MplayerWindow::setMonitorAspect(double asp) {
 	monitoraspect = asp;
@@ -229,44 +282,42 @@ void MplayerWindow::setAspect( double asp) {
 
 void MplayerWindow::updateVideoWindow()
 {
-	/*
-	mplayerlayer->resize(size());
-	return;
-	*/
-
 	//qDebug("MplayerWindow::updateVideoWindow");
 
     //qDebug("aspect= %f", aspect);
-    
+
     int w_width = size().width();
     int w_height = size().height();
+
+	int w = w_width;
+	int h = w_height;
+	int x = 0;
+	int y = 0;
+
+	if (aspect != 0) {
+	    int pos1_w = w_width;
+	    int pos1_h = w_width / aspect + 0.5;
     
-    int pos1_w = w_width;
-    int pos1_h = w_width / aspect + 0.5;
+	    int pos2_h = w_height;
+	    int pos2_w = w_height * aspect + 0.5;
     
-    int pos2_h = w_height;
-    int pos2_w = w_height * aspect + 0.5;
+	    //qDebug("pos1_w: %d, pos1_h: %d", pos1_w, pos1_h);
+	    //qDebug("pos2_w: %d, pos2_h: %d", pos2_w, pos2_h);
     
-    //qDebug("pos1_w: %d, pos1_h: %d", pos1_w, pos1_h);
-    //qDebug("pos2_w: %d, pos2_h: %d", pos2_w, pos2_h);
-    
-    int w,h;
-    int x=0;
-    int y=0;
-    
-    if (pos1_h <= w_height) {
-	//qDebug("Pos1!");
-		w = pos1_w;
-		h = pos1_h;
+	    if (pos1_h <= w_height) {
+		//qDebug("Pos1!");
+			w = pos1_w;
+			h = pos1_h;
 	
-		y = (w_height - h) /2;
-    } else {
-	//qDebug("Pos2!");
-		w = pos2_w;
-		h = pos2_h;
+			y = (w_height - h) /2;
+	    } else {
+		//qDebug("Pos2!");
+			w = pos2_w;
+			h = pos2_h;
 	
-		x = (w_width - w) /2;
-    }
+			x = (w_width - w) /2;
+	    }
+	}
 
     mplayerlayer->move(x,y);
     mplayerlayer->resize(w, h);
@@ -294,9 +345,20 @@ void MplayerWindow::mouseReleaseEvent( QMouseEvent * e) {
 		emit middleClicked();
 	}
 	else
+	if (e->button() == Qt::XButton1) {
+		e->accept();
+		emit xbutton1Clicked();
+	}
+	else
+	if (e->button() == Qt::XButton2) {
+		e->accept();
+		emit xbutton2Clicked();
+	}
+	else
     if (e->button() == Qt::RightButton) {
 		e->accept();
-		emit rightButtonReleased( e->globalPos() );
+		//emit rightButtonReleased( e->globalPos() );
+		emit rightClicked();
     } 
 	else {
 		e->ignore();
@@ -304,20 +366,43 @@ void MplayerWindow::mouseReleaseEvent( QMouseEvent * e) {
 }
 
 void MplayerWindow::mouseDoubleClickEvent( QMouseEvent * e ) {
-	e->accept();
-	emit doubleClicked();
+	if (e->button() == Qt::LeftButton) {
+		e->accept();
+		emit doubleClicked();
+	} else {
+		e->ignore();
+	}
 }
 
 void MplayerWindow::wheelEvent( QWheelEvent * e ) {
     qDebug("MplayerWindow::wheelEvent: delta: %d", e->delta());
     e->accept();
 
-    if (e->delta() >= 0)
-        emit wheelUp();
-    else
-        emit wheelDown();
+	if (e->orientation() == Qt::Vertical) {
+	    if (e->delta() >= 0)
+	        emit wheelUp();
+	    else
+	        emit wheelDown();
+	} else {
+		qDebug("MplayerWindow::wheelEvent: horizontal event received, doing nothing");
+	}
 }
 
+bool MplayerWindow::eventFilter( QObject * /*watched*/, QEvent * event ) {
+	//qDebug("MplayerWindow::eventFilter");
+
+	if ( (event->type() == QEvent::MouseMove) || 
+         (event->type() == QEvent::MouseButtonRelease) ) 
+	{
+		QMouseEvent *mouse_event = static_cast<QMouseEvent *>(event);
+
+		if (event->type() == QEvent::MouseMove) {
+			emit mouseMoved(mouse_event->pos());
+		}
+	}
+
+	return false;
+}
 
 QSize MplayerWindow::sizeHint() const {
 	//qDebug("MplayerWindow::sizeHint");
@@ -328,14 +413,6 @@ QSize MplayerWindow::minimumSizeHint () const {
 	return QSize(0,0);
 }
 
-
-void MplayerWindow::translatePos(QPoint p ) {
-	int x = p.x() + mplayerlayer->x();
-	int y = p.y() + mplayerlayer->y();
-
-	emit mouseMoved( QPoint(x,y) );
-}
-
 void MplayerWindow::setOffsetX( int d) {
 	offset_x = d;
 	mplayerlayer->move( orig_x + offset_x, mplayerlayer->y() );
@@ -360,7 +437,7 @@ void MplayerWindow::setZoom( double d) {
 	int w = orig_width;
 	int h = orig_height;
 
-	if (zoom_factor > 1.0) {
+	if (zoom_factor != 1.0) {
 		w = w * zoom_factor;
 		h = h * zoom_factor;
 
@@ -403,12 +480,12 @@ void MplayerWindow::moveDown() {
 }
 
 void MplayerWindow::incZoom() {
-	setZoom( zoom_factor + 0.10 );
+	setZoom( zoom_factor + ZOOM_STEP );
 }
 
 void MplayerWindow::decZoom() {
-	double zoom = zoom_factor - 0.10;
-	if (zoom < 1.0) zoom = 1.0;
+	double zoom = zoom_factor - ZOOM_STEP;
+	if (zoom < ZOOM_MIN) zoom = ZOOM_MIN;
 	setZoom( zoom );
 }
 
