@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,17 +35,17 @@
 class QWidget;
 class QLabel;
 class QKeyEvent;
+class QTimer;
 
-#if USE_GL_WIDGET
-#include <QGLWidget>
-#define SC_WIDGET QGLWidget
-#else
-#define SC_WIDGET QWidget
-#endif
+#define ZOOM_STEP 0.05
+#define ZOOM_MIN 0.5
+
+#define DELAYED_RESIZE 0
+#define NEW_MOUSE_CHECK_POS 1
 
 //! Screen is a widget that hides the mouse cursor after some seconds if not moved.
 
-class Screen : public SC_WIDGET
+class Screen : public QWidget
 {
 	Q_OBJECT
 
@@ -53,18 +53,21 @@ public:
 	Screen(QWidget* parent = 0, Qt::WindowFlags f = 0);
 	~Screen();
 
-signals:
-	void mouseMoved(QPoint);
-
 protected:
+#if !NEW_MOUSE_CHECK_POS
 	virtual void mouseMoveEvent( QMouseEvent * e );
+#endif
 	virtual void paintEvent ( QPaintEvent * e );
 
 protected slots:
 	virtual void checkMousePos();
 
 private:
+#if NEW_MOUSE_CHECK_POS
+	QPoint mouse_last_position;
+#else
 	QPoint cursor_pos, last_cursor_pos;
+#endif
 };
 
 //! MplayerLayer can be instructed to not delete the background.
@@ -77,12 +80,14 @@ public:
 	MplayerLayer(QWidget* parent = 0, Qt::WindowFlags f = 0);
 	~MplayerLayer();
 
+#if REPAINT_BACKGROUND_OPTION
 	//! If b is true, the background of the widget will be repainted as usual.
 	/*! Otherwise the background will not repainted when a video is playing. */
-	void allowClearingBackground(bool b);
+	void setRepaintBackground(bool b);
 
 	//! Return true if repainting the background is allowed.
-	bool isClearingBackgroundAllowed() { return allow_clearing; };
+	bool repaintBackground() { return repaint_background; };
+#endif
 
 public slots:
 	//! Should be called when a file has started. 
@@ -91,11 +96,15 @@ public slots:
 	//! Should be called when a file has stopped.
 	void playingStopped();
 
+#if REPAINT_BACKGROUND_OPTION
 protected:
 	virtual void paintEvent ( QPaintEvent * e );
+#endif
 
 private:
-	bool allow_clearing;
+#if REPAINT_BACKGROUND_OPTION
+	bool repaint_background;
+#endif
 	bool playing;
 };
 
@@ -117,7 +126,9 @@ public:
 	void setMonitorAspect(double asp);
 	void updateVideoWindow();
 
+#if USE_COLORKEY
 	void setColorKey(QColor c);
+#endif
 
 	void setOffsetX( int );
 	int offsetX();
@@ -134,6 +145,8 @@ public:
 	virtual QSize sizeHint () const;
 	virtual QSize minimumSizeHint() const;
 
+	virtual bool eventFilter( QObject * watched, QEvent * event );
+
 public slots:
 	void moveLeft();
 	void moveRight();
@@ -142,6 +155,11 @@ public slots:
 	void incZoom();
 	void decZoom();
 
+#if DELAYED_RESIZE
+protected slots:
+	void resizeLater();
+#endif
+
 protected:
 	virtual void retranslateStrings();
 	virtual void changeEvent ( QEvent * event ) ;
@@ -152,17 +170,18 @@ protected:
 	virtual void wheelEvent( QWheelEvent * e );
 	void moveLayer( int offset_x, int offset_y );
 
-protected slots:
-	virtual void translatePos(QPoint p );
-
 signals:
-    void rightButtonReleased( QPoint p );
+    //void rightButtonReleased( QPoint p );
 	void doubleClicked();
 	void leftClicked();
+	void rightClicked();
 	void middleClicked();
+	void xbutton1Clicked(); // first X button
+	void xbutton2Clicked(); // second X button
 	void keyPressed(QKeyEvent * e);
 	void wheelUp();
 	void wheelDown();
+	void mouseMoved(QPoint);
 
 protected:
     int video_width, video_height;
@@ -182,6 +201,10 @@ protected:
 	int orig_width, orig_height;
 
 	bool allow_video_movement;
+
+#if DELAYED_RESIZE
+	QTimer * resize_timer;
+#endif
 };
 
 
