@@ -78,6 +78,7 @@ Playlist::Playlist( Core *c, QWidget * parent, Qt::WindowFlags f)
 #else
 	automatically_get_info = true;
 #endif
+	play_files_from_start = true;
 
 	modified = false;
 
@@ -89,7 +90,7 @@ Playlist::Playlist( Core *c, QWidget * parent, Qt::WindowFlags f)
 	createActions();
 	createToolbar();
 
-	connect( core, SIGNAL(mediaFinished()), this, SLOT(playNext()) );
+	connect( core, SIGNAL(mediaFinished()), this, SLOT(playNext()), Qt::QueuedConnection );
 	connect( core, SIGNAL(mediaLoaded()), this, SLOT(getMediaInfo()) );
 
 	QVBoxLayout *layout = new QVBoxLayout;
@@ -111,6 +112,7 @@ Playlist::Playlist( Core *c, QWidget * parent, Qt::WindowFlags f)
 #endif
 
 	setAcceptDrops(true);
+	setAttribute(Qt::WA_NoMousePropagation);
 
 	// Random seed
 	QTime t;
@@ -138,6 +140,7 @@ void Playlist::setModified(bool mod) {
 
 void Playlist::createTable() {
 	listView = new MyTableWidget( 0, COL_TIME + 1, this);
+	listView->setObjectName("playlist_table");
 	listView->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
 	listView->setSelectionBehavior(QAbstractItemView::SelectRows);
 	listView->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -335,6 +338,8 @@ void Playlist::list() {
 }
 
 void Playlist::updateView() {
+	qDebug("Playlist::updateView");
+
 	listView->setRowCount( pl.count() );
 
 	//QString number;
@@ -347,7 +352,7 @@ void Playlist::updateView() {
 		time = Helper::formatTime( (int) pl[n].duration() );
 		
 		//listView->setText(n, COL_POS, number);
-		qDebug("name: '%s'", name.toUtf8().data());
+		qDebug("Playlist::updateView: name: '%s'", name.toUtf8().data());
 		listView->setText(n, COL_NAME, name);
 		listView->setText(n, COL_TIME, time);
 
@@ -767,7 +772,7 @@ void Playlist::playItem( int n ) {
 	qDebug("Playlist::playItem: %d (count:%d)", n, pl.count());
 
 	if ( (n >= pl.count()) || (n < 0) ) {
-		qDebug(" out of range");
+		qDebug("Playlist::playItem: out of range");
 		emit playlistEnded();
 		return;
 	}
@@ -780,7 +785,10 @@ void Playlist::playItem( int n ) {
 	if (!filename.isEmpty()) {
 		//pl[n].setPlayed(TRUE);
 		setCurrentItem(n);
-		core->open(filename, 0);
+		if (play_files_from_start) 
+			core->open(filename, 0);
+		else
+			core->open(filename);
 	}
 
 }
@@ -810,7 +818,11 @@ void Playlist::playNext() {
 
 void Playlist::playPrev() {
 	qDebug("Playlist::playPrev");
-	playItem( current_item-1 );
+	if (current_item > 0) {
+		playItem( current_item-1 );
+	} else {
+		if (pl.count() > 1) playItem( pl.count() -1 );
+	}
 }
 
 void Playlist::getMediaInfo() {
@@ -898,8 +910,8 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 		if ( (get_info) && (QFile::exists((*it))) ) {
 			data = InfoProvider::getInfo( (*it) );
 			addItem( (*it), data.displayName(), data.duration );
-			updateView();
-			qApp->processEvents();
+			//updateView();
+			//qApp->processEvents();
 		} else {
 			addItem( (*it), "", 0 );
 		}
@@ -907,9 +919,10 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
     	addItem( (*it), "", 0 );
 #endif
 
-		// FIXME: set latest_dir only if the file is a local file,
-        // to avoid that dvd:, vcd: and so on will be used.
-		/* latest_dir = QFileInfo((*it)).dirPath(TRUE); */
+		if (QFile::exists(*it)) {
+			latest_dir = QFileInfo((*it)).absolutePath();
+		}
+
         ++it;
     }
 #if USE_INFOPROVIDER
@@ -917,7 +930,7 @@ void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
 #endif
 	updateView();
 
-	qDebug( " * latest_dir: '%s'", latest_dir.toUtf8().data() );
+	qDebug( "Playlist::addFiles: latest_dir: '%s'", latest_dir.toUtf8().constData() );
 }
 
 void Playlist::addFile(QString file, AutoGetInfo auto_get_info) {
@@ -1136,11 +1149,13 @@ void Playlist::editPreferences() {
 	d.setDirectoryRecursion(recursive_add_directory);
 	d.setAutoGetInfo(automatically_get_info);
 	d.setSavePlaylistOnExit(save_playlist_in_config);
+	d.setPlayFilesFromStart(play_files_from_start);
 
 	if (d.exec() == QDialog::Accepted) {
 		recursive_add_directory = d.directoryRecursion();
 		automatically_get_info = d.autoGetInfo();
 		save_playlist_in_config = d.savePlaylistOnExit();
+		play_files_from_start = d.playFilesFromStart();
 	}
 }
 
@@ -1223,11 +1238,11 @@ void Playlist::saveSettings() {
 	set->setValue( "auto_get_info", automatically_get_info );
 	set->setValue( "recursive_add_directory", recursive_add_directory );
 	set->setValue( "save_playlist_in_config", save_playlist_in_config );
+	set->setValue( "play_files_from_start", play_files_from_start );
 
-//#if !DOCK_PLAYLIST
-	set->setValue( "window_width", size().width() );
-	set->setValue( "window_height", size().height() );
-//#endif
+#if !DOCK_PLAYLIST
+	set->setValue( "size", size() );
+#endif
 	set->setValue( "latest_dir", latest_dir );
 
 	set->endGroup();
@@ -1262,13 +1277,11 @@ void Playlist::loadSettings() {
 	automatically_get_info = set->value( "auto_get_info", automatically_get_info ).toBool();
 	recursive_add_directory = set->value( "recursive_add_directory", recursive_add_directory ).toBool();
 	save_playlist_in_config = set->value( "save_playlist_in_config", save_playlist_in_config ).toBool();
+	play_files_from_start = set->value( "play_files_from_start", play_files_from_start ).toBool();
 
-//#if !DOCK_PLAYLIST
-	QSize s;
-	s.setWidth( set->value( "window_width", size().width() ).toInt() );
-	s.setHeight( set->value( "window_height", size().height() ).toInt() );
-	resize( s );
-//#endif
+#if !DOCK_PLAYLIST
+	resize( set->value("size", size()).toSize() );
+#endif
 
 	latest_dir = set->value( "latest_dir", latest_dir ).toString();
 
