@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define _PLAYLIST_DOCK_H_
 
 #include <QDockWidget>
+#include "guiconfig.h"
 
 class PlaylistDock : public QDockWidget 
 {
@@ -31,13 +32,16 @@ public:
 
 signals:
 	void closed();
-	void docked();
-	void undocked();
+#if QT_VERSION < 0x040300
+	void visibilityChanged(bool visible);
+#endif
 
 protected:
-	virtual void closeEvent( QCloseEvent * event );
+	virtual void closeEvent( QCloseEvent * e );
+#if QT_VERSION < 0x040300
 	virtual void showEvent ( QShowEvent * event );
 	virtual void hideEvent ( QHideEvent * event );
+#endif
 };
 
 #endif
