@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include "prefinput.h"
 #include "prefsubtitles.h"
 #include "prefadvanced.h"
+#include "prefplaylist.h"
 
 #if USE_ASSOCIATIONS
 #include "prefassociations.h"
@@ -80,6 +81,9 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	page_input = new PrefInput;
 	addSection( page_input );
 
+	page_playlist = new PrefPlaylist;
+	addSection( page_playlist );
+
 #if USE_ASSOCIATIONS
 	page_associations = new PrefAssociations;
 	addSection(page_associations);
@@ -163,6 +167,7 @@ void PreferencesDialog::setData(Preferences * pref) {
 	page_input->setData(pref);
 	page_subtitles->setData(pref);
 	page_advanced->setData(pref);
+	page_playlist->setData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->setData(pref);
@@ -177,6 +182,7 @@ void PreferencesDialog::getData(Preferences * pref) {
 	page_input->getData(pref);
 	page_subtitles->getData(pref);
 	page_advanced->getData(pref);
+	page_playlist->getData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->getData(pref);
@@ -191,6 +197,7 @@ bool PreferencesDialog::requiresRestart() {
 	if (!need_restart) need_restart = page_input->requiresRestart();
 	if (!need_restart) need_restart = page_subtitles->requiresRestart();
 	if (!need_restart) need_restart = page_advanced->requiresRestart();
+	if (!need_restart) need_restart = page_playlist->requiresRestart();
 
 	return need_restart;
 }
@@ -207,7 +214,7 @@ void PreferencesDialog::changeEvent(QEvent *e) {
 	if (e->type() == QEvent::LanguageChange) {
 		retranslateStrings();
 	} else {
-		QWidget::changeEvent(e);
+		QDialog::changeEvent(e);
 	}
 }
 
