@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,9 +21,11 @@
 
 #include "ui_preferencesdialog.h"
 
+/*
 #ifdef Q_OS_WIN
 #define USE_ASSOCIATIONS 1
 #endif
+*/
 
 class QTextBrowser;
 class QPushButton;
@@ -36,6 +38,7 @@ class PrefSubtitles;
 class PrefInterface;
 class PrefInput;
 class PrefAdvanced;
+class PrefPlaylist;
 class PrefAssociations;
 
 class Preferences;
@@ -52,6 +55,7 @@ public:
 	PreferencesDialog( QWidget * parent = 0, Qt::WindowFlags f = 0 );
 	~PreferencesDialog();
 
+	PrefGeneral * mod_general() { return page_general; };
 	PrefInterface * mod_interface() { return page_interface; };
 	PrefInput * mod_input() { return page_input; };
 	PrefAdvanced * mod_advanced() { return page_advanced; };
@@ -91,6 +95,7 @@ protected:
 	PrefSubtitles * page_subtitles;
 	PrefInterface * page_interface;
 	PrefInput * page_input;
+	PrefPlaylist * page_playlist;
 	PrefAdvanced * page_advanced;
 
 #if USE_ASSOCIATIONS
