@@ -22,8 +22,16 @@
 #include "ui_prefgeneral.h"
 #include "prefwidget.h"
 #include "inforeader.h"
+#include "deviceinfo.h"
 #include "preferences.h"
 
+#ifdef Q_OS_WIN
+#define USE_DSOUND_DEVICES 1
+#else
+#define USE_ALSA_DEVICES 1
+#define USE_XV_ADAPTORS 1
+#endif
+
 class PrefGeneral : public PrefWidget, public Ui::PrefGeneral
 {
 	Q_OBJECT
@@ -43,11 +51,11 @@ public:
 	// Apply changes
 	void getData(Preferences * pref);
 
+    bool fileSettingsMethodChanged() { return filesettings_method_changed; };
+
 protected:
 	virtual void createHelp();
 
-	void setDrivers(InfoList vo_list, InfoList ao_list);
-
 	// Tab General
 	void setMplayerPath( QString path );
 	QString mplayerPath();
@@ -64,8 +72,11 @@ protected:
 	void setRememberSettings(bool b);
 	bool rememberSettings();
 
-	void setDontRememberTimePos(bool b);
-	bool dontRememberTimePos();
+	void setRememberTimePos(bool b);
+	bool rememberTimePos();
+
+	void setFileSettingsMethod(QString method);
+	QString fileSettingsMethod();
 
 	void setAudioLang(QString lang);
 	QString audioLang();
@@ -95,12 +106,18 @@ protected:
 	void setDisableScreensaver(bool b);
 	bool disableScreensaver();
 
+	void setBlackbordersOnFullscreen(bool b);
+	bool blackbordersOnFullscreen();
+
 	void setAutoq(int n);
 	int autoq();
 
 	void setSoftVol(bool b);
 	bool softVol();
 
+	void setUseAudioEqualizer(bool b);
+	bool useAudioEqualizer();
+
 	void setAc3DTSPassthrough(bool b);
 	bool Ac3DTSPassthrough();
 
@@ -113,12 +130,18 @@ protected:
 	void setInitialDeinterlace(int ID);
 	int initialDeinterlace();
 
+	void setInitialZoom(double v);
+	double initialZoom();
+
 	void setDirectRendering(bool b);
 	bool directRendering();
 
 	void setDoubleBuffer(bool b);
 	bool doubleBuffer();
 
+	void setUseSlices(bool b);
+	bool useSlices();
+
 	void setAmplification(int n);
 	int amplification();
 
@@ -138,8 +161,30 @@ protected:
 	void setScaleTempoFilter(Preferences::OptionState value);
 	Preferences::OptionState scaleTempoFilter();
 
+protected slots:
+	void vo_combo_changed(int);
+	void ao_combo_changed(int);
+
 protected:
 	virtual void retranslateStrings();
+	void updateDriverCombos();
+
+	InfoList vo_list;
+	InfoList ao_list;
+	
+#if USE_DSOUND_DEVICES
+	DeviceList dsound_devices;
+#endif
+
+#if USE_ALSA_DEVICES
+	DeviceList alsa_devices;
+#endif
+#if USE_XV_ADAPTORS
+	DeviceList xv_adaptors;
+#endif
+
+private:
+	bool filesettings_method_changed;
 };
 
 #endif
