@@ -20,7 +20,7 @@
 #include "prefinput.h"
 #include "images.h"
 #include "preferences.h"
-
+#include "config.h"
 #include "guiconfig.h"
 
 PrefInput::PrefInput(QWidget * parent, Qt::WindowFlags f)
@@ -45,6 +45,7 @@ QPixmap PrefInput::sectionIcon() {
 
 void PrefInput::createMouseCombos() {
 	left_click_combo->clear();
+	right_click_combo->clear();
 	double_click_combo->clear();
 	middle_click_combo->clear();
 	xbutton1_click_combo->clear();
@@ -62,10 +63,14 @@ void PrefInput::createMouseCombos() {
 	left_click_combo->addItem( tr("Go forward (short)"), "forward1" );
 	left_click_combo->addItem( tr("Go forward (medium)"), "forward2" );
 	left_click_combo->addItem( tr("Go forward (long)"), "forward3" );
+	left_click_combo->addItem( tr("Increase volume"), "increase_volume" );
+	left_click_combo->addItem( tr("Decrease volume"), "decrease_volume" );
 	left_click_combo->addItem( tr("Fullscreen"), "fullscreen" );
 	left_click_combo->addItem( tr("Compact"), "compact" );
 	left_click_combo->addItem( tr("Screenshot"), "screenshot" );
-	left_click_combo->addItem( tr("On top"), "on_top" );
+	left_click_combo->addItem( tr("Always on top"), "on_top_always" );
+	left_click_combo->addItem( tr("Never on top"), "on_top_never" );
+	left_click_combo->addItem( tr("On top while playing"), "on_top_while_playing" );
 	left_click_combo->addItem( tr("Mute"), "mute" );
 	left_click_combo->addItem( tr("OSD - Next level"), "next_osd" );
 	left_click_combo->addItem( tr("Playlist"), "show_playlist" );
@@ -75,8 +80,12 @@ void PrefInput::createMouseCombos() {
 	left_click_combo->addItem( tr("Frame counter"), "frame_counter" );
 	left_click_combo->addItem( tr("Preferences"), "show_preferences" );
 	left_click_combo->addItem( tr("Double size"), "toggle_double_size" );
-	left_click_combo->addItem( tr("Show equalizer"), "equalizer" );
+	left_click_combo->addItem( tr("Show video equalizer"), "video_equalizer" );
+	left_click_combo->addItem( tr("Show audio equalizer"), "audio_equalizer" );
 	left_click_combo->addItem( tr("Show context menu"), "show_context_menu" );
+#if DVDNAV_SUPPORT
+	left_click_combo->addItem( tr("Activate option in DVD menus"), "dvdnav_mouse" );
+#endif
 
 	// Copy to other combos
 	for (int n=0; n < left_click_combo->count(); n++) {
@@ -267,6 +276,12 @@ void PrefInput::createHelp() {
 	setWhatsThis(middle_click_combo, tr("Middle click"),
 		tr("Select the action for middle click on the mouse.") );
 
+	setWhatsThis(xbutton1_click_combo, tr("X Button 1"),
+		tr("Select the action for the X button 1.") );
+
+	setWhatsThis(xbutton2_click_combo, tr("X Button 2"),
+		tr("Select the action for the X button 2.") );
+
 	setWhatsThis(wheel_function_combo, tr("Wheel function"),
 		tr("Select the action for the mouse wheel.") );
 }
