@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,12 +53,21 @@ protected:
 	void setLeftClickFunction(QString f);
 	QString leftClickFunction();
 
+	void setRightClickFunction(QString f);
+	QString rightClickFunction();
+
 	void setDoubleClickFunction(QString f);
 	QString doubleClickFunction();
 
 	void setMiddleClickFunction(QString f);
 	QString middleClickFunction();
 
+	void setXButton1ClickFunction(QString f);
+	QString xButton1ClickFunction();
+
+	void setXButton2ClickFunction(QString f);
+	QString xButton2ClickFunction();
+
 	void setWheelFunction(int function);
 	int wheelFunction();
 
