@@ -17,49 +17,37 @@
 */
 
 #include "recents.h"
-#include "global.h"
-#include <QSettings>
 
-using namespace Global;
-
-Recents::Recents(QObject* parent) : QObject(parent) 
+Recents::Recents()
 {
 	l.clear();
 	max_items = 10;
-	load();
 }
 
 Recents::~Recents() {
-	save();
 }
 
 void Recents::clear() {
 	l.clear();
 }
 
-void Recents::add(QString s) {
-	qDebug("Recents::add: '%s'", s.toUtf8().data());
+int Recents::count() {
+	return l.count();
+}
 
-	/*
-	QStringList::iterator it = l.find(s);
-	if (it != l.end()) l.erase(it);
-	l.prepend(s);
+void Recents::setMaxItems(int n_items) {
+	max_items = n_items;
+	fromStringList(l);
+}
 
-	if (l.count() > max_items) l.erase(l.fromLast());
-	*/
+void Recents::addItem(QString s) {
+	qDebug("Recents::addItem: '%s'", s.toUtf8().data());
 
 	int pos = l.indexOf(s);
 	if (pos != -1) l.removeAt(pos);
 	l.prepend(s);
 
 	if (l.count() > max_items) l.removeLast();
-
-	//qDebug(" * current list:");
-	//list();
-}
-
-int Recents::count() {
-	return l.count();
 }
 
 QString Recents::item(int n) {
@@ -69,52 +57,25 @@ QString Recents::item(int n) {
 void Recents::list() {
 	qDebug("Recents::list");
 
-	for (int n=0; n < count(); n++) {
-		qDebug(" * item %d: '%s'", n, item(n).toUtf8().data() );
+	for (int n=0; n < l.count(); n++) {
+		qDebug(" * item %d: '%s'", n, l[n].toUtf8().constData() );
 	}
 }
 
-void Recents::save() {
-	qDebug("Recents::save");
-
-	QSettings * set = settings;
-
-	/*
-	set->beginGroup( "recent_files");
-
-	set->writeEntry( "items", count() );
-	for (int n=0; n < count(); n++) {
-		set->writeEntry("entry_" + QString::number(n), item(n) );
-	}
-	*/
-
-	set->beginGroup( "recent_files");
-	set->setValue( "files", l );
-
-	set->endGroup();
-}
-
-void Recents::load() {
-	qDebug("Recents::load");
-
+void Recents::fromStringList(QStringList list) {
 	l.clear();
 
-	QSettings * set = settings;
+	int max = list.count();
+	if (max_items < max) max = max_items;
 
-	/*
-	set->beginGroup( "recent_files");
+	//qDebug("max_items: %d, count: %d max: %d", max_items, l.count(), max);
 
-	int num_entries = set->readNumEntry( "items", 0 );
-	for (int n=0; n < num_entries; n++) {
-		QString s = set->readEntry("entry_" + QString::number(n), "" );
-		if (!s.isEmpty()) l.append( s );
+	for (int n = 0; n < max; n++) {
+		l.append( list[n] );
 	}
-	*/
-
-	set->beginGroup( "recent_files");
-	l = set->value( "files" ).toStringList();
-
-	set->endGroup();
 }
 
-#include "moc_recents.cpp"
+QStringList Recents::toStringList() {
+	return l;
+}
+
