@@ -20,34 +20,32 @@
 #define _RECENTS_H_
 
 #include <QStringList>
-#include <QObject>
 
-class Recents : public QObject
+class Recents
 {
-	Q_OBJECT
 
 public:
-	Recents(QObject* parent = 0);
-	~Recents();
+	Recents();
+	virtual ~Recents();
 
-	void add(QString s);
-	int count();
-	QString item(int n);
+	virtual void clear();
 
-	void setMaxItems(int n) { max_items = n; };
-	int maxItems() { return max_items; };
+	virtual void addItem(QString s);
+	virtual QString item(int n);
 
-	void save();
-	void load();
+	virtual int count();
 
-	void list();
+	virtual void setMaxItems(int n_items);
+	virtual int maxItems() { return max_items; };
 
-public slots:
-	void clear();
+	virtual void fromStringList(QStringList list);
+	virtual QStringList toStringList();
 
-private:
-	QStringList l;
+	virtual void list();
+
+protected:
 	int max_items;
+	QStringList l;
 };
 
 #endif
