@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -123,7 +123,16 @@ SubData SubTracks::findItem( SubData::Type t, int ID ) {
 }
 
 SubData SubTracks::itemAt( int n ) {
-	return subs[n];
+	if (n >= 0 && n < subs.count()) {
+		return subs[n];
+	} else {
+		qWarning("SubTracks::itemAt: %d out of range!", n);
+		qWarning("SubTracks::itemAt: returning an empty sub to avoid a crash");
+		qWarning("SubTracks::itemAt: this shouldn't happen, report a bug if you see this");
+
+		SubData empty_sub;
+		return empty_sub;
+	}
 }
 
 bool SubTracks::changeLang( SubData::Type t, int ID, QString lang ) {
@@ -150,8 +159,10 @@ bool SubTracks::changeFilename( SubData::Type t, int ID, QString filename ) {
 	return true;
 }
 
-void SubTracks::process(QString text) {
-	qDebug("SubTracks::process: '%s'", text.toUtf8().data());
+int SubTracks::parse(QString text) {
+	qDebug("SubTracks::parse: '%s'", text.toUtf8().data());
+
+	ParseResult result = SubtitleUnchanged;
 
 	QRegExp rx_subtitle("^ID_(SUBTITLE|FILE_SUB|VOBSUB)_ID=(\\d+)");
 	QRegExp rx_sid("^ID_(SID|VSID)_(\\d+)_(LANG|NAME)=(.*)");
@@ -169,9 +180,11 @@ void SubTracks::process(QString text) {
 			t = SubData::Sub;
 
 		if (find(t, ID) > -1) {
-			qWarning("SubTracks::process: subtitle type: %d, ID: %d already exists!", t, ID);
+			qWarning("SubTracks::parse: subtitle type: %d, ID: %d already exists!", t, ID);
 		} else {
 			add(t,ID);
+
+			result = SubtitleAdded;
 		}	
 	}
 	else
@@ -185,13 +198,15 @@ void SubTracks::process(QString text) {
 		if (type == "VSID") t = SubData::Vob;
 
 		if (find(t, ID) == -1) {
-			qWarning("SubTracks::process: subtitle type: %d, ID: %d doesn't exist!", t, ID);
+			qWarning("SubTracks::parse: subtitle type: %d, ID: %d doesn't exist!", t, ID);
 		} else {
 			if (attr=="NAME")
 				changeName(t,ID, value);
 			else
 				changeLang(t,ID, value);
-		}	
+
+			result = SubtitleChanged;
+		}
 	}
 	else
 	if (rx_subtitle_file.indexIn(text) > -1) {
@@ -200,9 +215,13 @@ void SubTracks::process(QString text) {
 			int last = subs.count() -1;
 			if (subs[last].type() == SubData::File) {
 				subs[last].setFilename( file );
+
+				result = SubtitleChanged;
 			}
 		}
 	}
+
+	return result;
 }
 
 /*
