@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -80,6 +80,8 @@ typedef QList <SubData> SubList;
 class SubTracks
 {
 public:
+	enum ParseResult { SubtitleUnchanged = 0, SubtitleAdded = 1, SubtitleChanged = 2 };
+
 	SubTracks();
 	~SubTracks();
 
@@ -100,7 +102,8 @@ public:
 	int findLang(QString expr);
 	int selectOne(QString preferred_lang, int default_sub=0);
 
-	void process(QString text);
+	//! Parses a line from mplayer output with subtitle info
+	int parse(QString text);
 
 	void list();
 	void listNames();
