@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2008 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,26 +19,69 @@
 #ifndef _TRACKS_H_
 #define _TRACKS_H_
 
-#include "trackdata.h"
+#include <QString>
 #include <QMap>
-#include <QSettings>
 
-class TrackList {
+/* Class to store info about video/audio tracks */
+
+class TrackData {
 
 public:
 
-	TrackList();
-	~TrackList();
+	TrackData() { _lang = ""; _name = "";_ID = -1; };
+	~TrackData() {};
+
+	void setLang( const QString & l ) { _lang = l; };
+	void setName( const QString & n ) { _name = n; };
+	void setID( int id ) { _ID = id; };
+
+	QString lang() const { return _lang; };
+	QString name() const { return _name; };
+	int ID() const { return _ID; };
+
+	QString displayName() const {
+		QString dname="";
+
+	    if (!_name.isEmpty()) {
+    	    dname = _name;
+			if (!_lang.isEmpty()) {
+				dname += " ["+ _lang + "]";
+			}
+		}
+	    else
+	    if (!_lang.isEmpty()) {
+	        dname = _lang;
+		}
+	    else
+	    dname = QString::number(_ID);
+
+		return dname;
+	}
+
+protected:
+
+	/* Language code: es, en, etc. */
+	QString _lang;
+
+	/* spanish, english... */
+	QString _name;
+
+	int _ID;
+};
+
+
+class Tracks {
+
+public:
+
+	Tracks();
+	~Tracks();
 
 	void clear();
 	void list();
 
 	void addLang(int ID, QString lang);
 	void addName(int ID, QString name);
-	void addFilename(int ID, QString filename);
-	void addDuration(int ID, double duration);
-	void addChapters(int ID, int n);
-	void addAngles(int ID, int n);
 	void addID(int ID);
 
 	int numItems();
@@ -50,18 +93,9 @@ public:
 
 	int findLang(QString expr);
 
-	// A mess for getting sub files...
-	int lastID();
-	bool existsFilename(QString name);
-
-	void save(QSettings & set);
-	void load(QSettings & set);
-
-
 protected:
 	typedef QMap <int, TrackData> TrackMap;
 	TrackMap tm;
 };
 
-
 #endif
